<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';

session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: admin_login.php");
    exit();
}

// دریافت شناسه مشتری از URL
if (!isset($_GET['customer_id'])) {
    die("شناسه خودرو نامعتبر است.");
}

$customer_id = intval($_GET['customer_id']);
$success_message = '';
$error_message = '';

// بررسی وجود شناسه مشتری در جدول customer_cars
$checkCarStmt = $pdo->prepare("SELECT * FROM customer_cars WHERE customer_id = ?");
$checkCarStmt->execute([$customer_id]);
$carExists = $checkCarStmt->fetch(PDO::FETCH_ASSOC);

if (!$carExists) {
    die("شناسه خودرو یافت نشد. لطفاً ابتدا اطلاعات خودرو را ثبت کنید.");
}

// دریافت تاریخ امروز به شمسی
$today_date = jdate('Y-m-d', time(), '', '', 'fa');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $service_date = $_POST['service_date'];
    $kilometer = $_POST['kilometer'];
    $next_kilometer = $_POST['next_kilometer'];
    $oil_type = $_POST['oil_type'];
    $amount_received = $_POST['amount_received'];
    $notes = isset($_POST['notes']) ? $_POST['notes'] : '';
    $items = $_POST['items'] ?? [];

    // بررسی شرایط اعتبارسنجی
    if ($service_date !== $today_date) {
        $error_message = "امکان ثبت سرویس فقط برای تاریخ امروز وجود دارد.";
    } elseif ($next_kilometer < $kilometer + 500) {
        $error_message = "کیلومتر بعدی باید حداقل 500 کیلومتر بیشتر از کیلومتر فعلی باشد.";
    } elseif (!is_numeric($amount_received) || $amount_received < 0) {
        $error_message = "لطفاً مبلغ دریافتی معتبر وارد کنید.";
    } else {
        try {
            // تبدیل تاریخ شمسی به میلادی برای ذخیره در دیتابیس
            list($year, $month, $day) = explode('-', $service_date);
            $gregorian_service_date = implode('-', jalali_to_gregorian($year, $month, $day));

            // بررسی سرویس تکراری برای همان خودرو و تاریخ
            $checkServiceStmt = $pdo->prepare("SELECT COUNT(*) FROM services WHERE car_id = ? AND service_date = ?");
            $checkServiceStmt->execute([$carExists['id'], $gregorian_service_date]);
            $existing_service = $checkServiceStmt->fetchColumn();

            if ($existing_service > 0) {
                $error_message = "امکان ثبت سرویس برای این خودرو در این تاریخ وجود ندارد.";
            } else {
                // درج اطلاعات سرویس در جدول services
                $stmt = $pdo->prepare("INSERT INTO services (car_id, service_date, kilometer, next_kilometer, oil_type, amount_received, notes) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute([$carExists['id'], $gregorian_service_date, $kilometer, $next_kilometer, $oil_type, $amount_received, $notes]);

                // دریافت شناسه سرویس ثبت‌شده
                $service_id = $pdo->lastInsertId();

                // درج آیتم‌های سرویس در جدول service_items
                foreach ($items as $item => $action_type) {
                    $stmt = $pdo->prepare("INSERT INTO service_items (service_id, item_name, action_type) VALUES (?, ?, ?)");
                    $stmt->execute([$service_id, $item, $action_type]);
                }

                $success_message = "سرویس با موفقیت ثبت شد.";
            }
        } catch (PDOException $e) {
            $error_message = "خطایی رخ داد: " . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ثبت سرویس خودرو</title>
    <link rel="stylesheet" href="../../../public/css/service.css">
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet">
</head>
<body>
<div class="container">
    <h1>ثبت سرویس خودرو</h1>

    <?php if ($error_message): ?>
        <div class="alert error"><?= $error_message ?></div>
    <?php endif; ?>

    <?php if ($success_message): ?>
        <div class="alert success"><?= $success_message ?></div>
    <?php endif; ?>

    <form method="POST" action="">
        <label for="service_date">تاریخ سرویس:</label>
        <input type="text" name="service_date" id="service_date" required value="<?= jdate('Y-m-d'); ?>">

        <label for="oil_type">نوع روغن موتور:</label>
        <input type="text" name="oil_type" id="oil_type" required>

        <label for="kilometer">کیلومتر فعلی:</label>
        <input type="text" onkeypress="return /[0-9]/i.test(event.key)" name="kilometer" id="kilometer" required>

        <label for="next_kilometer">کیلومتر بعدی:</label>
        <input type="text" onkeypress="return /[0-9]/i.test(event.key)" name="next_kilometer" id="next_kilometer" required>

        <label for="amount_received">مبلغ دریافتی (تومان):</label>
        <input type="text" onkeypress="return /[0-9]/i.test(event.key)" name="amount_received" id="amount_received" required>

        <label for="notes">یادداشت‌ها:</label>
        <textarea name="notes" id="notes" rows="4"></textarea>

        <h3>آیتم‌های سرویس:</h3>
        <div class="service-items">
            <?php
            // دریافت لیست آیتم‌های سرویس از جدول service_items_list
            $stmt = $pdo->query("SELECT item_name FROM service_items_list");
            while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                $item_name = $row['item_name'];
                echo "
                <div class='service-item'>
                    <span>$item_name</span>
                    <div class='radio-group'>
                        <label><input type='radio' name='items[$item_name]' value='تعویض'> تعویض</label>
                        <label><input type='radio' name='items[$item_name]' value='بازدید'> بازدید</label>
                    </div>
                </div>";
            }
            ?>
        </div>

        <button type="submit" class="btn-submit">ثبت سرویس</button>
        <a href="admin_dashboard.php" class="btn-return">بازگشت به داشبورد</a>
    </form>
</div>
</body>
</html>
