<?php
require '../../../config/config.php';
session_start();

$error_message = '';
$success_message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['login'])) {
        // پردازش فرم ورود
        $username = $_POST['username'];
        $password = $_POST['password'];

        $stmt = $pdo->prepare("SELECT * FROM admins WHERE username = ?");
        $stmt->execute([$username]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($user && password_verify($password, $user['password'])) {
            $_SESSION['admin_logged_in'] = true;
            $_SESSION['user_id'] = $user['id'];
            header("Location: admin_dashboard.php");
            exit();
        } else {
            $error_message = "نام کاربری یا رمز عبور اشتباه است.";
        }
    } elseif (isset($_POST['register'])) {
        // پردازش فرم ثبت‌نام
        $username = $_POST['username'];
        $password = $_POST['password'];
        $confirm_password = $_POST['confirm_password'];

        if ($password !== $confirm_password) {
            $error_message = "رمز عبور و تأیید رمز عبور مطابقت ندارند.";
        } else {
            $hashed_password = password_hash($password, PASSWORD_DEFAULT);
            $stmt = $pdo->prepare("INSERT INTO admins (username, password) VALUES (?, ?)");
            if ($stmt->execute([$username, $hashed_password])) {
                $success_message = "ثبت‌نام با موفقیت انجام شد.";
            } else {
                $error_message = "خطا در ثبت‌نام. لطفاً دوباره تلاش کنید.";
            }
        }
    }
}
?>
<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>سامانه مدیریت مشتریان</title>
    
    <link rel="manifest" href="manifest.json">
    <link rel="icon" type="image/x-icon" href="../../../images/download.ico">
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet">
    <link rel="stylesheet" href="../../../public/css/alogin.css">
    <script>
        if ("serviceWorker" in navigator) {
            navigator.serviceWorker
                .register("/sw.js")
                .then(() => console.log("Service Worker Registered"))
                .catch((err) => console.error("Service Worker Registration Failed", err));
        }
    </script>
</head>
<body>
    <div class="login-container">
        <!-- تصویر مدیریت اتوسرویس -->
        <img src="../../../images/oil_service.jpg" alt="مدیریت اتوسرویس">

        <h1>ورود مدیر</h1>

        <?php if (isset($error_message)): ?>
            <p class="error-message"><?= htmlspecialchars($error_message) ?></p>
        <?php endif; ?>

        <?php if (isset($success_message)): ?>
            <p class="success-message"><?= htmlspecialchars($success_message) ?></p>
        <?php endif; ?>

        <form method="POST">
            <label for="username">:نام کاربری</label>
            <input type="text" id="username" name="username" required>

            <label for="password">:رمز عبور</label>
            <input type="password" id="password" name="password" required>

            <button type="submit" name="login">ورود</button>
        </form>

        <h2>ثبت‌نام</h2>

        <form method="POST">
            <label for="username">:نام کاربری</label>
            <input type="text" id="username" name="username" required>

            <label for="password">:رمز عبور</label>
            <input type="password" id="password" name="password" required>

            <label for="confirm_password">:تأیید رمز عبور</label>
            <input type="password" id="confirm_password" name="confirm_password" required>

            <button type="submit" name="register">ثبت‌نام</button>
        </form>

        <p style="margin-top: 10px; color: #555;">نسخه 1.1.0</p>
    </div>
</body>
</html>