<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: admin_login.php");
    exit();
}

$success_message = '';
$error_message = '';
$search_query = '';
$where_clause = '';

// بررسی وجود پارامتر جستجو
if (isset($_GET['search_query'])) {
    $search_query = trim($_GET['search_query']);
    if (!empty($search_query)) {
        $where_clause = "WHERE c.full_name LIKE :search_query OR c.phone_number LIKE :search_query";
    }
}

// صفحه‌بندی
$rows_per_page = 10;
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $rows_per_page;

// واکشی تعداد کل ردیف‌ها
$total_rows_stmt = $pdo->prepare("SELECT COUNT(*) FROM customers c $where_clause");
if (!empty($where_clause)) {
    $total_rows_stmt->execute([':search_query' => "%$search_query%"]);
} else {
    $total_rows_stmt->execute();
}
$total_rows = $total_rows_stmt->fetchColumn();
$total_pages = ceil($total_rows / $rows_per_page);

// واکشی لیست مشتریان به همراه خودروهای آن‌ها با صفحه‌بندی
$query = "
    SELECT c.*, cc.car_model 
    FROM customers c 
    LEFT JOIN customer_cars cc ON c.id = cc.customer_id 
    $where_clause
    ORDER BY c.created_at DESC 
    LIMIT $rows_per_page OFFSET $offset
";
$stmt = $pdo->prepare($query);
if (!empty($where_clause)) {
    $stmt->execute([':search_query' => "%$search_query%"]);
} else {
    $stmt->execute();
}
$customers = $stmt->fetchAll(PDO::FETCH_ASSOC);

// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

// ماسک کردن شماره موبایل
function maskPhoneNumber($phone_number) {
    if (strlen($phone_number) !== 11) {
        return $phone_number; // اگر شماره موبایل معتبر نباشد، همان مقدار را برگردانید
    }
    return substr($phone_number, 7) . '***' . substr($phone_number, 0, 4);
}

$today = jdate('l j F ماه Y');
$today = englishToPersian($today);
?>
<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>داشبورد مدیریت</title>
    <link rel="icon" type="image/x-icon" href="../../../images/download.ico">
    <link rel="stylesheet" href="../../../public/css/styles.css">
</head>
<body>
<header>
    <h1>به سامانه مدیریت مشتریان اتوسرویس خوش آمدید</h1>
    <p>امروز، <?= $today ?></p><br>
    <a href="add_customers.php" target="_blank">ثبت مشتری</a>
    <a href="report.php">گزارش</a>
    <a href="logout.php" class="logout-btn">خروج</a>
</header>

<section class="customer-list">
    <h2>لیست مشتریان</h2>

    <form method="GET" action="">
        <input type="text" name="search_query" placeholder="جستجو بر اساس نام یا شماره موبایل" value="<?= htmlspecialchars($search_query) ?>">
        <button type="submit">جستجو</button>
    </form>

    <table>
        <thead>
            <tr>
                <th>کد مشتری</th>
                <th>نام و نام خانوادگی</th>
                <th>شماره موبایل</th>
                <th>خودرو</th>
                <th>عملیات</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($customers) > 0): ?>
                <?php foreach ($customers as $customer): ?>
                    <tr>
                        <td><a href="edit_customer.php?customer_id=<?= $customer['id'] ?>"><?= htmlspecialchars($customer['customer_number']) ?></a></td>
                        <td><?= htmlspecialchars($customer['full_name']) ?></td>
                        <td><?= englishToPersian(maskPhoneNumber(htmlspecialchars($customer['phone_number']))) ?></td>
                        <td><?= $customer['car_model'] ? htmlspecialchars($customer['car_model']) : 'تخصیص داده نشده' ?></td>
                        <td><a href="add_service.php?customer_id=<?= $customer['id'] ?>">ثبت سرویس</a></td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="5">مشتری با این مشخصات یافت نشد</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>

    <div class="pagination">
        <?php if ($page > 1): ?>
            <a href="?page=<?= $page - 1 ?>&search_query=<?= htmlspecialchars($search_query) ?>">قبلی</a>
        <?php endif; ?>
        <?php for ($i = 1; $i <= $total_pages; $i++): ?>
            <a href="?page=<?= $i ?>&search_query=<?= htmlspecialchars($search_query) ?>" class="<?= $i === $page ? 'active' : '' ?>"><?= $i ?></a>
        <?php endfor; ?>
        <?php if ($page < $total_pages): ?>
            <a href="?page=<?= $page + 1 ?>&search_query=<?= htmlspecialchars($search_query) ?>">بعدی</a>
        <?php endif; ?>
    </div>
</section>
</body>
</html>
