<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: admin_login.php");
    exit();
}


// بررسی دریافت شناسه مشتری
if (!isset($_GET['customer_id'])) {
    header("Location: admin_dashboard.php");
    exit();
}

$customer_id = intval($_GET['customer_id']);

// واکشی اطلاعات مشتری
$stmt = $pdo->prepare("SELECT * FROM customers WHERE id = ?");
$stmt->execute([$customer_id]);
$customer = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$customer) {
    echo "مشتری یافت نشد.";
    exit();
}

// واکشی خودروهای ثبت شده برای مشتری
$stmt = $pdo->prepare("SELECT * FROM customer_cars WHERE customer_id = ?");
$stmt->execute([$customer_id]);
$cars = $stmt->fetchAll(PDO::FETCH_ASSOC);

// ویرایش اطلاعات مشتری
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_customer'])) {
    $full_name = trim($_POST['full_name']);
    $phone_number = trim($_POST['phone_number']);

    if (empty($full_name) || empty($phone_number)) {
        $error_message = "لطفاً تمام فیلدهای ضروری را پر کنید.";
    } else {
        try {
            $stmt = $pdo->prepare("UPDATE customers SET full_name = ?, phone_number = ? WHERE id = ?");
            $stmt->execute([$full_name, $phone_number, $customer_id]);
            $success_message = "اطلاعات مشتری با موفقیت به‌روزرسانی شد.";
            header("Location: edit_customer.php?customer_id=$customer_id&success=1");
            exit();
        } catch (PDOException $e) {
            $error_message = "خطایی رخ داد: " . $e->getMessage();
        }
    }
}

// افزودن یا ویرایش خودروی مشتری
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_or_update_car'])) {
    $car_id = isset($_POST['car_id']) ? intval($_POST['car_id']) : null;
    $car_model = trim($_POST['car_model']);
    $plate_part1 = trim($_POST['plate_part1']);
    $plate_part2 = trim($_POST['plate_part2']);
    $plate_part3 = trim($_POST['plate_part3']);
    $plate_part4 = trim($_POST['plate_part4']);

    if (empty($car_model)) {
        $error_message = "لطفاً تمام فیلدهای ضروری را پر کنید.";
    } else {
        try {
            if ($car_id) {
                // ویرایش خودرو
                $stmt = $pdo->prepare("UPDATE customer_cars SET car_model = ?, plate_part1 = ?, plate_part2 = ?, plate_part3 = ?, plate_part4 = ? WHERE id = ?");
                $stmt->execute([$car_model, $plate_part1, $plate_part2, $plate_part3, $plate_part4,  $car_id]);
                $success_message = "اطلاعات خودرو با موفقیت به‌روزرسانی شد.";
            } else {
                // افزودن خودرو جدید
                $stmt = $pdo->prepare("INSERT INTO customer_cars (customer_id, car_model, plate_part1, plate_part2, plate_part3, plate_part4) VALUES (?, ?, ?, ?, ?, ?)");
                $stmt->execute([$customer_id, $car_model, $plate_part1, $plate_part2, $plate_part3, $plate_part4]);
                $success_message = "خودروی جدید با موفقیت اضافه شد.";
            }
            header("Location: edit_customer.php?customer_id=$customer_id&success=1");
            exit();
        } catch (PDOException $e) {
            $error_message = "خطایی رخ داد: " . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ویرایش مشتری</title>
    <link rel="stylesheet" href="../../../public/css/edit.css">
    <link rel="manifest" href="manifest.json">
    <link rel="icon" type="image/x-icon" href="download.ico">
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet">
    <script>
        if ("serviceWorker" in navigator) {
            navigator.serviceWorker
                .register("/sw.js")
                .then(() => console.log("Service Worker Registered"))
                .catch((err) => console.error("Service Worker Registration Failed", err));
        }
    </script>
</head>
<body>
    <header>
        <h1>ویرایش اطلاعات مشتری</h1>
    </header>
    <section>
        <h2>اطلاعات مشتری</h2>
        <form method="POST">
            <label for="full_name">نام و نام خانوادگی:</label>
            <input type="text" id="full_name" name="full_name" value="<?= htmlspecialchars($customer['full_name']) ?>" required>

            <label for="phone_number">شماره موبایل:</label>
            <input type="text" id="phone_number" name="phone_number" value="<?= htmlspecialchars($customer['phone_number']) ?>" required>

            <button type="submit" name="update_customer">ذخیره تغییرات</button>
        </form>

        <?php if (!empty($success_message)): ?>
            <div class="success-message"><?= $success_message ?></div>
        <?php endif; ?>

        <?php if (!empty($error_message)): ?>
            <div class="error-message"><?= $error_message ?></div>
        <?php endif; ?>
    </section>

    <section>
        <h2>خودروهای ثبت شده</h2>
        <table>
            <thead>
                <tr>
                    <th>مدل خودرو</th>
                    <th>رقم اول</th>
                    <th>حرف</th>
                    <th>رقم وسط</th>
                    <th>کد شهر</th>
                    <th>عملیات</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($cars as $car): ?>
                    <tr>
                        <form method="POST">
                            <input type="hidden" name="car_id" value="<?= $car['id'] ?>">
                            <td><input type="text" name="car_model" value="<?= htmlspecialchars($car['car_model']) ?>" required></td>
                            <td><input type="text" name="plate_part1" value="<?= htmlspecialchars($car['plate_part1']) ?>" maxlength="2" required></td>
                            <td><input type="text" name="plate_part2" value="<?= htmlspecialchars($car['plate_part2']) ?>" maxlength="1" required></td>
                            <td><input type="text" name="plate_part3" value="<?= htmlspecialchars($car['plate_part3']) ?>" maxlength="3" required></td>
                            <td><input type="text" name="plate_part4" value="<?= htmlspecialchars($car['plate_part4']) ?>" maxlength="2" required></td>
                            <td><button type="submit" name="add_or_update_car">ذخیره</button></td>
                        </form>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <h3>افزودن خودروی جدید</h3>
        <form method="POST">
            <label for="car_model">مدل خودرو<span style="color:red; font-size: 25px;">*</span></label>
            <input type="text" id="car_model" name="car_model" required>

            <label for="plate_part1">رقم اول<span style="color:red; font-size: 25px;">*</span></label>
            <input type="text" id="plate_part1" name="plate_part1" maxlength="2" required>

            <label for="plate_part2">حرف پلاک<span style="color:red; font-size: 25px;">*</span></label>
            <input type="text" id="plate_part2" name="plate_part2" maxlength="1" required>

            <label for="plate_part3">رقم وسط<span style="color:red; font-size: 25px;">*</span></label>
            <input type="text" id="plate_part3" name="plate_part3" maxlength="3" required>

            <label for="plate_part4">کد شهر<span style="color:red; font-size: 25px;">*</span></label>
            <input type="text" id="plate_part4" name="plate_part4" maxlength="2" required>

            <button type="submit" name="add_or_update_car">افزودن خودرو</button>
            <a href="admin_dashboard.php" class="btn-return">بازگشت به داشبورد</a>
        </form>
    </section>
</body>
</html>
