<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';

session_start();

if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: admin_login.php");
    exit();
}

$error_message = '';
$report_data = [];
$search_query = '';
$start_date = '';
$end_date = '';
$plate_part3 = '';
$total_amount_received = 0;

function persianToEnglish($number) {
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    return str_replace($persian, $english, $number);
}

function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $search_query = trim($_GET['customer_name'] ?? '');
    $start_date = trim($_GET['start_date'] ?? '');
    $end_date = trim($_GET['end_date'] ?? '');
    $plate_part3 = trim($_GET['plate_part3'] ?? '');

    try {
        $query = "
            SELECT s.*, c.full_name, c.phone_number, cc.plate_part3,
                   GROUP_CONCAT(CONCAT(si.item_name, ': ', si.action_type) SEPARATOR ' | ') AS service_items 
            FROM services s 
            JOIN customer_cars cc ON s.car_id = cc.id 
            JOIN customers c ON cc.customer_id = c.id 
            LEFT JOIN service_items si ON s.id = si.service_id 
        ";

        $conditions = [];
        $params = [];

        if (!empty($search_query)) {
            $conditions[] = "c.full_name LIKE :search_query";
            $params[':search_query'] = "%$search_query%";
        }

        if (!empty($plate_part3)) {
            $plate_part3_english = persianToEnglish($plate_part3);
            $plate_part3_persian = englishToPersian($plate_part3);

            $conditions[] = "(cc.plate_part3 LIKE :plate_part3_english OR cc.plate_part3 LIKE :plate_part3_persian)";
            $params[':plate_part3_english'] = "%$plate_part3_english%";
            $params[':plate_part3_persian'] = "%$plate_part3_persian%";
        }

        if (!empty($start_date) && !empty($end_date)) {
            list($start_year, $start_month, $start_day) = explode('-', $start_date);
            list($end_year, $end_month, $end_day) = explode('-', $end_date);

            $gregorian_start_date = implode('-', jalali_to_gregorian($start_year, $start_month, $start_day));
            $gregorian_end_date = implode('-', jalali_to_gregorian($end_year, $end_month, $end_day));

            $conditions[] = "s.service_date BETWEEN :start_date AND :end_date";
            $params[':start_date'] = $gregorian_start_date;
            $params[':end_date'] = $gregorian_end_date;
        }

        if (!empty($conditions)) {
            $query .= " WHERE " . implode(" AND ", $conditions);
        }

        $query .= " GROUP BY s.id ORDER BY s.service_date ASC";

        $stmt = $pdo->prepare($query);
        $stmt->execute($params);
        $report_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

        foreach ($report_data as $service) {
            $total_amount_received += $service['amount_received'];
        }

        if (empty($report_data)) {
            $error_message = "هیچ سرویسی یافت نشد.";
        }
    } catch (PDOException $e) {
        $error_message = "خطایی در واکشی داده‌ها رخ داد: " . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>گزارش‌گیری</title>
    <link rel="stylesheet" href="../../../public/css/report.css">
</head>
<body>
<div class="container">
    <h1>گزارش‌گیری از سرویس‌ها</h1>

    <?php if ($error_message): ?>
        <div class="alert error"><?= $error_message ?></div>
    <?php endif; ?>

    <!-- فرم جستجو -->
    <form method="GET" action="">
    <label for="customer_name">نام مشتری:</label>
    <input type="text" name="customer_name" id="customer_name" placeholder="مثال: حسن رضایی" 
           value="<?= htmlspecialchars($search_query) ?>">

    <label for="plate_part3">شماره پلاک:</label>
    <input type="text" name="plate_part3" id="plate_part3" placeholder="مثال: 12الف345" 
           value="<?= htmlspecialchars($plate_part3) ?>">

    <label for="start_date">تاریخ شروع:</label>
    <input type="text" name="start_date" id="start_date" placeholder="مثال: 1401-01-01" 
           value="<?= htmlspecialchars($start_date) ?>">

    <label for="end_date">تاریخ پایان:</label>
    <input type="text" name="end_date" id="end_date" placeholder="مثال: 1401-12-29" 
           value="<?= htmlspecialchars($end_date) ?>">

    <button type="submit" class="btn-submit">دریافت گزارش</button>
</form>


    <?php if (!empty($report_data)): ?>
        <h2>پیش‌نمایش گزارش</h2>
        <table>
            <thead>
                <tr>
                    <th>تاریخ سرویس</th>
                    <th>نوع روغن</th>
                    <th>کیلومتر فعلی</th>
                    <th>کیلومتر بعدی</th>
                    <th>نام مشتری</th>
                    <th>مبلغ دریافتی</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($report_data as $service): ?>
                    <tr>
                        <td>
                            <a href="service_items.php?service_id=<?= $service['id'] ?>">
                                <?php
                                if (!empty($service['service_date']) && $service['service_date'] !== '0000-00-00') {
                                    list($gy, $gm, $gd) = explode('-', $service['service_date']);
                                    list($jy, $jm, $jd) = gregorian_to_jalali($gy, $gm, $gd);
                                    echo englishToPersian("$jy/$jm/$jd");
                                } else {
                                    echo "نامشخص";
                                }
                                ?>
                            </a>
                        </td>
                        <td><?= htmlspecialchars($service['oil_type']) ?></td>
                        <td><?= englishToPersian(htmlspecialchars($service['kilometer'])) ?></td>
                        <td><?= englishToPersian(htmlspecialchars($service['next_kilometer'])) ?></td>
                        <td><?= htmlspecialchars($service['full_name']) ?></td>
                        <td><?= englishToPersian(htmlspecialchars($service['amount_received'])) ?> تومان</td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- نمایش مجموع مبالغ دریافتی -->
        <p><strong>جمع کل مبالغ دریافتی: </strong><?= englishToPersian(number_format($total_amount_received)) ?> تومان</p>
    <?php endif; ?>

    <a href="admin_dashboard.php" class="btn-return">بازگشت به داشبورد</a>
</div>
</body>
</html>

