<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

// تابع ثبت لاگ
function logActivity($pdo, $admin_id, $action) {
    $ip_address = $_SERVER['REMOTE_ADDR'];
    $stmt = $pdo->prepare("INSERT INTO activity_logs (admin_id, action, ip_address) VALUES (?, ?, ?)");
    $stmt->execute([$admin_id, $action, $ip_address]);
}

// ثبت مشتری جدید
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_customer'])) {
    $full_name = trim($_POST['full_name']);
    $phone_number = trim($_POST['phone_number']);

    if (empty($full_name) || empty($phone_number)) {
        $error_message = "لطفاً تمام فیلدهای ضروری را پر کنید.";
    } else {
        try {
            // شروع تراکنش
            $pdo->beginTransaction();

            // واکشی بیشترین شماره مشتری موجود
            $stmt = $pdo->query("SELECT MAX(customer_number) FROM customers");
            $last_number = $stmt->fetchColumn();

            // تولید شماره مشتری یکتا
            $next_number = ($last_number) ? intval(substr($last_number, 5)) + 1 : 1;
            $customer_number = sprintf("CUST-%04d", $next_number);

            // ذخیره اطلاعات مشتری
            $stmt = $pdo->prepare("INSERT INTO customers (customer_number, full_name, phone_number) VALUES (?, ?, ?)");
            $stmt->execute([$customer_number, $full_name, $phone_number]);

            // ثبت لاگ فعالیت
            $admin_id = $_SESSION['admin_id'];
            logActivity($pdo, $admin_id, "ثبت مشتری جدید: $full_name با شماره $customer_number");

            // تایید تراکنش
            $pdo->commit();

            // ارسال پیامک خوش‌آمدگویی
            $username = "9179397191";
            $password = "a94da764-5d76-4688-bece-85390a2b766b";
            $from = "5000400012345";
            $to = $phone_number;
            $text = "مشتری عزیز *$full_name*\nمشخصات شما با موفقیت ثبت شد\nاتو سرویس ";

            $api_url = "https://api.payamak-panel.com/post/sendsms.ashx";

            // مقداردهی اولیه cURL
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $api_url);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query([
                'username' => $username,
                'password' => $password,
                'to' => $to,
                'from' => $from,
                'text' => $text
            ]));
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

            // اجرای درخواست و دریافت پاسخ
            $response = curl_exec($ch);

            // بررسی خطای cURL
            if (curl_errno($ch)) {
                $error_message = "خطای ارسال پیامک: " . curl_error($ch);
            } else {
                $success_message = "مشتری جدید با شماره $customer_number با موفقیت ثبت شد و پیامک خوش‌آمدگویی ارسال شد.";
            }

            // بستن cURL
            curl_close($ch);

        } catch (PDOException $e) {
            $pdo->rollBack(); // بازگردانی تراکنش در صورت خطا
            $error_message = "خطایی رخ داد: " . $e->getMessage();
        }
    }
}
?>



<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ثبت مشتری جدید</title>
    <link rel="icon" type="image/x-icon" href="../../../images/download.ico">
    <link rel="stylesheet" href="../../../public/css/add.css">
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet">
</head>
<body>
    <header>
        <h1>ثبت مشتری جدید</h1>
    </header>
    <section>
        <form method="POST">
            <label for="full_name">نام و نام خانوادگی:</label>
            <input type="text" id="full_name" name="full_name" required>

            <label for="phone_number">شماره موبایل:</label>
            <input type="text" 
                   id="phone_number" 
                   name="phone_number" 
                   inputmode="numeric" 
                   onkeypress="return /[0-9]/i.test(event.key)" 
                   maxlength="11" 
                   required>

            <button type="submit" name="add_customer">ثبت مشتری</button>
            <a href="admin_dashboard" class="btn-return">بازگشت به داشبورد</a>
        </form>

        <?php if (!empty($success_message)): ?>
            <p class="success-message"><?= $success_message ?></p>
        <?php endif; ?>

        <?php if (!empty($error_message)): ?>
            <p class="error-message"><?= $error_message ?></p>
        <?php endif; ?>
    </section>
</body>
</html>