<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';

session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

// ایجاد توکن CSRF
if (empty($_SESSION['csrf_token'])) {
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
}

// تابع ثبت لاگ
function logActivity($pdo, $admin_id, $action) {
    $ip_address = $_SERVER['REMOTE_ADDR'];
    $stmt = $pdo->prepare("INSERT INTO activity_logs (admin_id, action, ip_address) VALUES (?, ?, ?)");
    $stmt->execute([$admin_id, $action, $ip_address]);
}

// دریافت شناسه مشتری
if (!isset($_GET['customer_id']) || !ctype_digit($_GET['customer_id'])) {
    die("شناسه مشتری نامعتبر است.");
}

$customer_id = intval($_GET['customer_id']);
$success_message = '';
$error_message = '';

try {
    // دریافت خودروهای مشتری
    $stmt = $pdo->prepare("SELECT * FROM customer_cars WHERE customer_id = ?");
    $stmt->execute([$customer_id]);
    $cars = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if (!$cars) {
        die("هیچ خودرویی برای این مشتری ثبت نشده است.");
    }
} catch (PDOException $e) {
    die("خطایی رخ داد: " . $e->getMessage());
}

// تاریخ امروز شمسی
$today_date = jdate('Y-m-d', time(), '', '', 'fa');
// محاسبه تاریخ مراجعه بعدی (مثلاً 78 روز بعد)
$next_service_date = jdate('Y-m-d', strtotime('+78 days'), '', '', 'fa');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // بررسی توکن CSRF
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        die("توکن CSRF نامعتبر است.");
    }

    // اعتبارسنجی و پاکسازی داده‌های ورودی
    $car_id = isset($_POST['car_id']) ? intval($_POST['car_id']) : 0;
    $service_date = htmlspecialchars($_POST['service_date'], ENT_QUOTES, 'UTF-8');
    $kilometer = isset($_POST['kilometer']) ? intval($_POST['kilometer']) : 0;
    $next_kilometer = isset($_POST['next_kilometer']) ? intval($_POST['next_kilometer']) : 0;
    $oil_type = htmlspecialchars($_POST['oil_type'], ENT_QUOTES, 'UTF-8');
    $amount_received = isset($_POST['amount_received']) ? floatval($_POST['amount_received']) : 0;
    $notes = isset($_POST['notes']) ? htmlspecialchars($_POST['notes'], ENT_QUOTES, 'UTF-8') : '';
    $items = isset($_POST['items']) ? $_POST['items'] : [];

    // بررسی آخرین سرویس خودرو
    $stmt = $pdo->prepare("SELECT kilometer FROM services WHERE car_id = ? ORDER BY service_date DESC LIMIT 1");
    $stmt->execute([$car_id]);
    $last_service = $stmt->fetch(PDO::FETCH_ASSOC);
    $last_kilometer = $last_service ? $last_service['kilometer'] : 0;

    // اعتبارسنجی اطلاعات
    if (empty($car_id)) {
        $error_message = "لطفاً یک خودرو انتخاب کنید.";
    } elseif ($service_date !== $today_date) {
        $error_message = "امکان ثبت سرویس فقط برای تاریخ امروز وجود دارد.";
    } elseif ($last_kilometer > 0 && $kilometer <= $last_kilometer) {
        $error_message = "کیلومتر فعلی باید بیشتر از کیلومتر آخرین سرویس باشد.";
    } elseif ($next_kilometer < $kilometer + 2000) {
        $error_message = "کیلومتر بعدی باید حداقل 2000 کیلومتر بیشتر از کیلومتر فعلی باشد.";
    } elseif (!is_numeric($amount_received) || $amount_received < 0) {
        $error_message = "لطفاً مبلغ دریافتی معتبر وارد کنید.";
    } else {
        try {
            // تبدیل تاریخ شمسی به میلادی
            list($year, $month, $day) = explode('-', $service_date);
            $gregorian_service_date = implode('-', jalali_to_gregorian($year, $month, $day));

            list($next_year, $next_month, $next_day) = explode('-', $next_service_date);
            $gregorian_next_service_date = implode('-', jalali_to_gregorian($next_year, $next_month, $next_day));

            // درج اطلاعات سرویس
            $stmt = $pdo->prepare("
                INSERT INTO services (customer_id, car_id, service_date, next_service_date, kilometer, next_kilometer, oil_type, amount_received, notes) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([$customer_id, $car_id, $gregorian_service_date, $gregorian_next_service_date, $kilometer, $next_kilometer, $oil_type, $amount_received, $notes]);

            // دریافت شناسه سرویس ثبت‌شده
            $service_id = $pdo->lastInsertId();

            // درج آیتم‌های سرویس
            if (!empty($items)) {
                foreach ($items as $item => $action_type) {
                    $item_name = htmlspecialchars($item, ENT_QUOTES, 'UTF-8');
                    $action_type = htmlspecialchars($action_type, ENT_QUOTES, 'UTF-8');
                    $stmt = $pdo->prepare("INSERT INTO service_items (service_id, item_name, action_type) VALUES (?, ?, ?)");
                    $stmt->execute([$service_id, $item_name, $action_type]);
                }
            }

            // ثبت لاگ
            $admin_id = $_SESSION['admin_id'];
            logActivity($pdo, $admin_id, "ثبت سرویس جدید برای خودرو ID $car_id");

            // ارسال پیامک به مشتری
            $stmt = $pdo->prepare("SELECT phone_number FROM customers WHERE id = ?");
            $stmt->execute([$customer_id]);
            $customer = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($customer) {
                $customer_phone = $customer['phone_number'];
                $next_service_date_formatted = jdate('d-m-Y', strtotime($gregorian_next_service_date), '', '', 'fa');
                $service_link = "https://hassansalari.ir/app/views/customer/service_items?service_id=$service_id";
                $sms_message = "مشتری گرامی، سرویس خودروی شما انجام شد.\nتاریخ مراجعه بعدی: $next_service_date_formatted\nمشاهده جزئیات سرویس: $service_link\nاتوسرویس الف";

                // ارسال پیامک
                $sms_api_url = "https://api.payamak-panel.com/post/sendsms.ashx";
                $sms_params = [
                    'username' => '9179397191',
                    'password' => 'a94da764-5d76-4688-bece-85390a2b766b',
                    'to' => $customer_phone,
                    'from' => '5000400012345',
                    'text' => $sms_message,
                ];

                // ذخیره پیامک در دیتابیس
                $stmt = $pdo->prepare("
                    INSERT INTO sent_sms (customer_id, phone_number, message, service_id, sent_at) 
                    VALUES (?, ?, ?, ?, NOW())
                ");
                $stmt->execute([$customer_id, $customer_phone, $sms_message, $service_id]);

                file_get_contents($sms_api_url . '?' . http_build_query($sms_params));
            }

            // پیام موفقیت و هدایت به داشبورد
            $success_message = "سرویس با موفقیت ثبت شد.";
            header("Location: admin_dashboard.php");
            exit();
        } catch (PDOException $e) {
            $error_message = "خطایی رخ داد: " . $e->getMessage();
        }
    }
}

$pdo->prepare("UPDATE customers SET last_visit = CURDATE() WHERE id = :customer_id")
    ->execute([':customer_id' => $customer_id]);

?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ثبت سرویس خودرو</title>
    <link rel="stylesheet" href="../../../public/css/service.css">
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/persian-datepicker/dist/css/persian-datepicker.min.css">
    <script src="https://cdn.jsdelivr.net/npm/persian-datepicker/dist/js/persian-date.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/persian-datepicker/dist/js/persian-datepicker.min.js"></script>
</head>
<body>
<div class="container">
    <h1>ثبت سرویس خودرو</h1>

    <?php if ($error_message): ?>
        <div class="alert error"><?= $error_message ?></div>
    <?php endif; ?>

    <?php if ($success_message): ?>
        <div class="alert success"><?= $success_message ?></div>
    <?php endif; ?>

    <form method="POST" action="">
        <input type="hidden" name="csrf_token" value="<?= $_SESSION['csrf_token'] ?>">

        <label for="car_id">انتخاب خودرو:</label>
        <select name="car_id" id="car_id" required>
            <option value="">لطفاً یک خودرو انتخاب کنید</option>
            <?php foreach ($cars as $car): ?>
                <option value="<?= htmlspecialchars($car['id'], ENT_QUOTES, 'UTF-8') ?>">
                    <?= htmlspecialchars($car['car_model'], ENT_QUOTES, 'UTF-8') ?> - پلاک: <?= htmlspecialchars($car['plate_part4'] . ' ' . $car['plate_part3'] . ' ' . $car['plate_part2'] . ' ' . $car['plate_part1'], ENT_QUOTES, 'UTF-8') ?>
                </option>
            <?php endforeach; ?>
        </select>

        <label for="service_date">تاریخ سرویس:</label>
        <input type="text" name="service_date" id="service_date" required value="<?= $today_date; ?>" readonly>

        <input type="text" name="oil_type" id="oil_type" required placeholder="نوع روغن موتور">

        <input type="text" onkeypress="return /[0-9]/.test(event.key)" name="kilometer" id="kilometer" required placeholder="کیلومتر فعلی">

        <input type="text" onkeypress="return /[0-9]/.test(event.key)" name="next_kilometer" id="next_kilometer" required placeholder="کیلومتر بعدی">

        <label for="next_service_date">تاریخ مراجعه بعدی(تقریبی):</label>
        <input type="text" name="next_service_date" id="next_service_date" value="<?= $next_service_date; ?>" readonly>

        <input type="text" onkeypress="return (event.key)" name="amount_received" id="amount_received" required placeholder="مبلغ دریافت شده">

        <textarea name="notes" id="notes" rows="4" placeholder="یادداشت‌ها"></textarea>

        <h3>آیتم‌های سرویس:</h3>
        <div class="service-items">
            <?php
            $stmt = $pdo->query("SELECT item_name FROM service_items_list");
            while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                $item_name = htmlspecialchars($row['item_name'], ENT_QUOTES, 'UTF-8');
                echo "
                <div class='service-item'>
                    <span>$item_name</span>
                    <div class='radio-group'>
                        <label><input type='radio' name='items[$item_name]' value='تعویض'> تعویض</label>
                        <label><input type='radio' name='items[$item_name]' value='بازدید'> بازدید</label>
                    </div>
                </div>";
            }
            ?>
        </div>

        <button type="submit" class="btn-submit">ثبت سرویس</button>
        <a href="admin_dashboard" class="btn-return">بازگشت به داشبورد</a>
    </form>
</div>
</body>
</html>