<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();



// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

// دریافت مجموع پرداختی‌های هر ماه در سال جاری
$income_stmt = $pdo->query("
    SELECT service_date, SUM(amount_received) AS total_income
    FROM services
    WHERE YEAR(service_date) = YEAR(CURRENT_DATE)
    GROUP BY MONTH(service_date)
    ORDER BY MONTH(service_date)
");

$monthly_income = [];
while ($row = $income_stmt->fetch(PDO::FETCH_ASSOC)) {
    // تبدیل تاریخ میلادی به شمسی
    $shamsi_month = jdate('m', strtotime($row['service_date']), '', '', 'en');
    $monthly_income[$shamsi_month] = $row['total_income'];
}

// ایجاد آرایه‌ای برای ۱۲ ماه سال، حتی اگر مقدار برخی از ماه‌ها صفر باشد
$income_data = [];
for ($i = 1; $i <= 12; $i++) {
    $income_data[] = $monthly_income[$i] ?? 0; // مقدار پیش‌فرض صفر برای ماه‌هایی که داده ندارند
}

// تعداد کل مشتریان
$total_customers_stmt = $pdo->query("SELECT COUNT(*) FROM customers");
$total_customers = $total_customers_stmt->fetchColumn();

// تعداد سرویس‌های انجام‌شده در ماه جاری
$current_month = date('Y-m'); // مقدار صحیح برای مقایسه با 'YYYY-MM'
$services_stmt = $pdo->prepare("SELECT COUNT(*) FROM services WHERE DATE_FORMAT(service_date, '%Y-%m') = :current_month");
$services_stmt->execute(['current_month' => $current_month]);
$total_services = $services_stmt->fetchColumn();

// دریافت مجموع پرداختی‌های ماه جاری
$stmt = $pdo->query("SELECT SUM(amount_received) AS total_received 
                     FROM services 
                     WHERE MONTH(service_date) = MONTH(CURRENT_DATE) 
                     AND YEAR(service_date) = YEAR(CURRENT_DATE)");

$row = $stmt->fetch(PDO::FETCH_ASSOC);
$total_received = $row['total_received'] ?? 0; // اگر مقدار null بود، ۰ نمایش دهد


// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

$today = jdate('l j F ماه Y');
$today = englishToPersian($today);
?>


<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>داشبورد مدیریت</title>
    <link href="https://cdn.jsdelivr.net/gh/rastikerdar/vazir-font@v30.1.0/dist/font-face.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        body {
            font-family: 'Vazir', sans-serif;
        }

        /* استایل‌های کلی هدر */
        header {
            background-color: #4a5568;
            color: white;
            padding: 1rem;
            width: 100%;
            z-index: 1000;
        }

        /* حالت موبایل */
        @media (max-width: 768px) {
            header {
                position: fixed;
                top: 0;
                left: 0;
                right: 0;
            }

            main {
                padding-top: 70px;
            }
        }
    </style>
</head>
<body class="bg-gray-100 text-gray-800">

    <!-- هدر -->
      <!-- هدر -->
      <header class="bg-gray-800 text-white py-4 fixed top-0 left-0 right-0 z-50 shadow-lg transition-shadow duration-300">
    <div class="container mx-auto flex justify-between items-center px-4">
        <div class="flex items-center">
            <div>
                <p class="text-sm">امروز، <?= $today ?></p>
            </div>
        </div>
        <nav class="hidden md:flex space-x-4">
            <a href="customers" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">لیست مشتریان</a>
            <a href="add_customers" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">ثبت مشتری</a>
            <a href="report" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">گزارش</a>
            <a href="sent_sms" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">گزارش پیام‌ها</a>
            <a href="logout" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">خروج</a>
        </nav>
        <button class="md:hidden p-2 focus:outline-none" id="menu-toggle">
            <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M4 6h16M4 12h16m-7 6h7"></path>
            </svg>
        </button>
    </div>
    <!-- منوی موبایل -->
    <div class="md:hidden bg-gray-700 mt-2 hidden" id="mobile-menu">
        <a href="add_customers" class="block px-4 py-2 hover:bg-gray-600">ثبت مشتری</a>
        <a href="report" class="block px-4 py-2 hover:bg-gray-600">گزارش</a>
        <a href="customers" class="block px-4 py-2 hover:bg-gray-600">لیست مشتریان</a>
        <a href="sent_sms" class="block px-4 py-2 hover:bg-gray-600">گزارش پیام‌ها</a>
        <a href="logout" class="block px-4 py-2 bg-red-500 hover:bg-red-600">خروج</a>
    </div>
</header>
<div class="container mx-auto px-4 py-8 mt-16">
    <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
        <div class="bg-white p-6 rounded-lg shadow-md hover:shadow-lg transition-shadow text-center">
            <div class="bg-blue-100 p-4 rounded-full inline-block">
                <svg class="w-8 h-8 text-blue-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M17 20h5v-2a3 3 0 00-5.356-1.857M17 20H7m10 0v-2c0-.656-.126-1.283-.356-1.857M7 20H2v-2a3 3 0 015.356-1.857M7 20v-2c0-.656.126-1.283.356-1.857m0 0a5.002 5.002 0 019.288 0M15 7a3 3 0 11-6 0 3 3 0 016 0zm6 3a2 2 0 11-4 0 2 2 0 014 0zM7 10a2 2 0 11-4 0 2 2 0 014 0z"/>
                </svg>
            </div>
            <h3 class="text-xl font-bold mt-4"><?= englishToPersian($total_customers) ?></h3>
            <p class="text-gray-600">تعداد کل مشتریان</p>
        </div>

        <div class="bg-white p-6 rounded-lg shadow-md hover:shadow-lg transition-shadow text-center">
            <div class="bg-green-100 p-4 rounded-full inline-block">
                <svg class="w-8 h-8 text-green-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 8v4l3 3m6-3a9 9 0 11-18 0 9 9 0 0118 0z"/>
                </svg>
            </div>
            <h3 class="text-xl font-bold mt-4"><?= englishToPersian($total_services) ?></h3>
            <p class="text-gray-600">تعداد سرویس‌های این ماه</p>
        </div>

        <div class="bg-white p-6 rounded-lg shadow-md hover:shadow-lg transition-shadow text-center">
            <div class="bg-purple-100 p-4 rounded-full inline-block">
                <svg class="w-8 h-8 text-purple-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 8c-1.657 0-3 .895-3 2s1.343 2 3 2 3 .895 3 2-1.343 2-3 2m0-8c1.11 0 2.08.402 2.599 1M12 8V7m0 1v8m0 0v1m0-1c-1.11 0-2.08-.402-2.599-1M21 12a9 9 0 11-18 0 9 9 0 0118 0z"/>
                </svg>
            </div>
            <h3 class="text-xl font-bold mt-4"><?= englishToPersian(number_format($total_received)) ?> تومان</h3>
            <p class="text-gray-600">دریافتی ها این ماه</p>
        </div>
    </div>
</div>

<!-- نوار نمودار -->
<div class="bg-white p-6 rounded-lg shadow-md text-center">
    <h3 class="text-xl font-bold">نمودار درآمد ماهانه</h3>
    <div style="width: 100%; height: 400px; overflow-y: scroll; overflow-x: hidden;">
        <canvas id="incomeChart" style="max-width: 100%;"></canvas>
    </div>
</div>


<script>
document.addEventListener("DOMContentLoaded", function() {
    var ctx = document.getElementById('incomeChart').getContext('2d');
    var incomeChart = new Chart(ctx, {
        type: 'line',
        data: {
            labels: ['فروردین', 'اردیبهشت', 'خرداد', 'تیر', 'مرداد', 'شهریور', 'مهر', 'آبان', 'آذر', 'دی', 'بهمن', 'اسفند'],
            datasets: [{
                label: 'درآمد ماهانه (تومان)',
                data: <?= json_encode($income_data) ?>,
                borderColor: '#4CAF50',
                backgroundColor: 'rgba(76, 175, 80, 0.2)',
                borderWidth: 2,
                tension: 0.3
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                y: {
                    beginAtZero: true,
                    ticks: {
                        callback: function(value) {
                            return new Intl.NumberFormat().format(value) + ' تومان';
                        }
                    }
                }
            }
        }
    });
});
</script>

<script>
    document.addEventListener("DOMContentLoaded", function () {
        const menuToggle = document.getElementById("menu-toggle");
        const mobileMenu = document.getElementById("mobile-menu");

        menuToggle.addEventListener("click", function () {
            mobileMenu.classList.toggle("hidden");
        });
    });
</script>

</body>
</html>
