<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

$success_message = '';
$error_message = '';
$search_query = '';
$where_clause = '';

// بررسی وجود پارامتر جستجو
if (isset($_GET['search_query'])) {
    $search_query = trim($_GET['search_query']);
    if (!empty($search_query)) {
        $where_clause = "WHERE c.full_name LIKE :search_query OR c.phone_number LIKE :search_query";
    }
}

// صفحه‌بندی
$rows_per_page = 12;
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $rows_per_page;

// واکشی تعداد کل ردیف‌ها
$total_rows_stmt = $pdo->prepare("SELECT COUNT(*) FROM customers c $where_clause");
if (!empty($where_clause)) {
    $total_rows_stmt->execute([':search_query' => "%$search_query%"]);
} else {
    $total_rows_stmt->execute();
}
$total_rows = $total_rows_stmt->fetchColumn();
$total_pages = ceil($total_rows / $rows_per_page);

// واکشی لیست مشتریان با صفحه‌بندی
$query = "
    SELECT c.* 
    FROM customers c 
    $where_clause
    ORDER BY c.created_at DESC 
    LIMIT $rows_per_page OFFSET $offset
";
$stmt = $pdo->prepare($query);
if (!empty($where_clause)) {
    $stmt->execute([':search_query' => "%$search_query%"]);
} else {
    $stmt->execute();
}
$customers = $stmt->fetchAll(PDO::FETCH_ASSOC);

// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

// ماسک کردن شماره موبایل
function maskPhoneNumber($phone_number) {
    if (strlen($phone_number) !== 11) {
        return $phone_number;
    }
    return substr($phone_number, 7)  . '****' . substr($phone_number, 0, 3) ;
    
}

$today = jdate('l j F ماه Y');
$today = englishToPersian($today);
?>
<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>داشبورد مدیریت</title>
    <link href="https://cdn.jsdelivr.net/gh/rastikerdar/vazir-font@v30.1.0/dist/font-face.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Vazir', sans-serif;
        }

        /* استایل‌های کلی هدر */
        header {
            background-color: #4a5568;
            color: white;
            padding: 1rem;
            width: 100%;
            z-index: 1000;
        }

        /* حالت موبایل */
        @media (max-width: 768px) {
            header {
                position: fixed;
                top: 0;
                left: 0;
                right: 0;
            }

            main {
                padding-top: 70px;
            }
        }
    </style>
</head>
<body class="bg-gray-100 text-gray-800">

    <!-- هدر -->
    <header class="bg-gray-800 text-white py-4 fixed top-0 left-0 right-0 z-50 shadow-lg transition-shadow duration-300">
    <div class="container mx-auto flex justify-between items-center px-4">
        <div class="flex items-center">
            <div>
                <p class="text-sm">امروز، <?= $today ?></p>
            </div>
        </div>
        <nav class="hidden md:flex space-x-4">
            <a href="admin_dashboard" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">داشبورد</a>
            <a href="add_customers" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">ثبت مشتری</a>
            <a href="report" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">گزارش</a>
            <a href="sent_sms" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">گزارش پیام‌ها</a>
            <a href="logout" class="px-4 py-2 hover:bg-gray-700 rounded-lg transition-colors">خروج</a>
        </nav>
        <button class="md:hidden p-2 focus:outline-none" id="menu-toggle">
            <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M4 6h16M4 12h16m-7 6h7"></path>
            </svg>
        </button>
    </div>
    <!-- منوی موبایل -->
    <div class="md:hidden bg-gray-700 mt-2 hidden" id="mobile-menu">
        <a href="add_customers" class="block px-4 py-2 hover:bg-gray-600">ثبت مشتری</a>
        <a href="report" class="block px-4 py-2 hover:bg-gray-600">گزارش</a>
        <a href="customers" class="block px-4 py-2 hover:bg-gray-600">لیست مشتریان</a>
        <a href="sent_sms" class="block px-4 py-2 hover:bg-gray-600">گزارش پیام‌ها</a>
        <a href="logout" class="block px-4 py-2 bg-red-500 hover:bg-red-600">خروج</a>
    </div>
</header>


    <!-- بخش اصلی -->
    <main class="container mx-auto px-4 py-8">
        <h2 class="text-2xl font-bold mb-6">لیست مشتریان</h2>

        <!-- فرم جستجو -->
        <form method="GET" action="" class="mb-6">
            <div class="flex">
                <input type="text" name="search_query" placeholder="جستجو بر اساس نام یا شماره موبایل" value="<?= htmlspecialchars($search_query) ?>"
                       class="flex-1 p-2 border border-gray-300 rounded-l focus:outline-none focus:border-blue-500">
                <button type="submit" class="bg-blue-500 text-white px-4 py-2 rounded-r hover:bg-blue-600 flex items-center">
                    <svg class="w-5 h-5 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0z"></path>
                    </svg>
                    جستجو
                </button>
            </div>
        </form>

           <!-- لیست مشتریان (کارت‌محور) -->
        <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
            <?php if (count($customers) > 0): ?>
                <?php foreach ($customers as $customer): ?>
                    <div class="bg-white p-6 rounded-lg shadow-md hover:shadow-lg transition-shadow">
                        <h3 class="text-lg font-semibold mb-2"><?= htmlspecialchars($customer['full_name']) ?></h3>
                        <p class="text-gray-600 mb-2"><?= englishToPersian(maskPhoneNumber(htmlspecialchars($customer['phone_number']))) ?></p>
                        <p class="text-gray-600 mb-4">کد مشتری: <?= htmlspecialchars($customer['customer_number']) ?></p>
                        <div class="flex space-x-4">
                            <a href="edit_customer?customer_id=<?= $customer['id'] ?>" class="bg-blue-500 text-white px-4 py-2 rounded hover:bg-blue-600">ویرایش</a>
                            <a href="add_service?customer_id=<?= $customer['id'] ?>" class="bg-green-500 text-white px-4 py-2 rounded hover:bg-green-600">ثبت سرویس</a>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php else: ?>
                <p class="text-center text-gray-600">مشتری با این مشخصات یافت نشد.</p>
            <?php endif; ?>
        </div>

        <!-- صفحه‌بندی -->
        <div class="flex flex-wrap justify-between items-center mt-8">
    <div class="mb-4 md:mb-0">
         </div>
    <div class="flex gap-1">
        <?php if ($page > 1): ?>
            <a href="?page=<?= $page-1 ?>" class="px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600">« قبلی</a>
        <?php endif; ?>
        
        <?php for ($i=1; $i<=$total_pages; $i++): ?>
            <a href="?page=<?= $i ?>" class="px-4 py-2 <?= $i==$page ? 'bg-blue-500 text-white' : 'bg-gray-100 hover:bg-gray-200' ?> rounded">
                <?= $i ?>
            </a>
        <?php endfor; ?>
        
        <?php if ($page < $total_pages): ?>
            <a href="?page=<?= $page+1 ?>" class="px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600">بعدی »</a>
        <?php endif; ?>
    </div>
</div>
    </main>

    <!-- اسکریپت برای منوی موبایل -->
    <script>
        document.getElementById('menu-toggle').addEventListener('click', function() {
            const mobileMenu = document.getElementById('mobile-menu');
            mobileMenu.classList.toggle('hidden');
        });
    </script>
</body>
</html>