<?php
require '../../../config/config.php';
session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

// دریافت شناسه خودرو از URL
if (!isset($_GET['car_id'])) {
    die("شناسه خودرو نامعتبر است.");
}
$car_id = intval($_GET['car_id']);

// واکشی اطلاعات خودرو
try {
    $stmt = $pdo->prepare("SELECT * FROM customer_cars WHERE id = ?");
    $stmt->execute([$car_id]);
    $car = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$car) {
        die("خودرو یافت نشد.");
    }
} catch (PDOException $e) {
    die("خطایی رخ داد: " . $e->getMessage());
}

// پردازش فرم ویرایش
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $car_model = trim($_POST['car_model']);
    $plate_part1 = trim($_POST['plate_part1']);
    $plate_part2 = trim($_POST['plate_part2']);
    $plate_part3 = trim($_POST['plate_part3']);
    $plate_part4 = trim($_POST['plate_part4']);

    if (empty($car_model) || empty($plate_part1) || empty($plate_part2) || empty($plate_part3) || empty($plate_part4)) {
        $error_message = "لطفاً تمام فیلدها را پر کنید.";
    } else {
        try {
            $stmt = $pdo->prepare("UPDATE customer_cars SET car_model = ?, plate_part1 = ?, plate_part2 = ?, plate_part3 = ?, plate_part4 = ? WHERE id = ?");
            $stmt->execute([$car_model, $plate_part1, $plate_part2, $plate_part3, $plate_part4, $car_id]);

            // ثبت لاگ ویرایش خودرو
            logActivity($pdo, $_SESSION['admin_id'], "ویرایش خودرو با شناسه $customer_id");

            $success_message = "اطلاعات خودرو با موفقیت به‌روزرسانی شد.";
            header("Location: edit_customer.php?customer_id=" . $car['customer_id']);
            exit();
        } catch (PDOException $e) {
            $error_message = "خطایی در به‌روزرسانی اطلاعات رخ داد: " . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ویرایش خودرو</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
body {
    font-family: 'Yekan', sans-serif;
    background-color: #f8f9fa;
    color: #212529;
    direction: rtl;
    text-align: right;
    padding: 20px;
}

.container {
    max-width: 800px;
    margin: auto;
    background: #ffffff;
    padding: 30px;
    border-radius: 12px;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
}

h1, h2 {
    color: #343a40;
    margin-bottom: 20px;
}

h1 {
    font-size: 28px;
    font-weight: bold;
    color:rgb(28, 15, 105);
    text-align: center;
}

h2 {
    font-size: 22px;
    font-weight: 600;
}

/* فرم‌ها */
form {
    margin-bottom: 30px;
}

.form-label {
    font-weight: bold;
    color: #495057;
    margin-bottom: 8px;
}

.form-control {
    padding: 10px;
    border: 1px solid #ced4da;
    border-radius: 6px;
    font-size: 14px;
    transition: border-color 0.3s ease, box-shadow 0.3s ease;
}

.form-control:focus {
    border-color: #80bdff;
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
}

/* دکمه‌ها */
.btn {
    font-size: 14px;
    border-radius: 6px;
    padding: 10px 20px;
    transition: background-color 0.3s ease, transform 0.2s ease;
}

.btn-primary {
    background-color: #007bff;
    border-color: #007bff;
}

.btn-primary:hover {
    background-color: #0056b3;
    border-color: #004085;
    transform: translateY(-1px);
}

.btn-success {
    background-color: #28a745;
    border-color: #28a745;
}

.btn-success:hover {
    background-color: #218838;
    border-color: #1e7e34;
    transform: translateY(-1px);
}

.btn-secondary {
    background-color: #6c757d;
    border-color: #6c757d;
}

.btn-secondary:hover {
    background-color: #5a6268;
    border-color: #545b62;
    transform: translateY(-1px);
}

/* جدول */
table {
    width: 100%;
    border-collapse: collapse;
    margin-top: 20px;
    background-color: #fff;
    border-radius: 8px;
    overflow: hidden;
    box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
}

table th, table td {
    border: 1px solid #dee2e6;
    padding: 12px;
    text-align: center;
}

table th {
    background-color: #007bff;
    color: #fff;
    font-weight: bold;
}

table tr:nth-child(even) {
    background-color: #f8f9fa;
}

table tr:hover {
    background-color: #e9ecef;
}

/* پیام‌ها */
.alert {
    margin-top: 15px;
    padding: 12px;
    border-radius: 6px;
    font-size: 14px;
}

.alert-success {
    background-color: #d4edda;
    color: #155724;
    border: 1px solid #c3e6cb;
}

.alert-danger {
    background-color: #f8d7da;
    color: #721c24;
    border: 1px solid #f5c6cb;
}

/* واکنش‌گرایی */
@media (max-width: 768px) {
    .container {
        padding: 20px;
    }

    h1 {
        font-size: 24px;
    }

    h2 {
        font-size: 20px;
    }

    .form-control {
        font-size: 12px;
    }

    .btn {
        font-size: 12px;
        padding: 8px 16px;
    }

    table th, table td {
        padding: 8px;
    }
}    </style>
</head>
<body>
    <div class="container">
        <h1>ویرایش خودرو</h1>

        <?php if (!empty($success_message)): ?>
            <div class="alert alert-success"><?= $success_message ?></div>
        <?php endif; ?>
        <?php if (!empty($error_message)): ?>
            <div class="alert alert-danger"><?= $error_message ?></div>
        <?php endif; ?>

        <form method="POST">
            <div class="mb-3">
                <label for="car_model" class="form-label">مدل خودرو:</label>
                <input type="text" id="car_model" name="car_model" class="form-control" value="<?= htmlspecialchars($car['car_model']) ?>" required>
            </div>
            <div class="row">
                <div class="col-md-3">
                    <label for="plate_part1" class="form-label">رقم اول:</label>
                    <input type="text" id="plate_part1" name="plate_part1" class="form-control" maxlength="2" value="<?= htmlspecialchars($car['plate_part1']) ?>" required>
                </div>
                <div class="col-md-3">
                    <label for="plate_part2" class="form-label">حرف:</label>
                    <input type="text" id="plate_part2" name="plate_part2" class="form-control" maxlength="1" value="<?= htmlspecialchars($car['plate_part2']) ?>" required>
                </div>
                <div class="col-md-3">
                    <label for="plate_part3" class="form-label">رقم وسط:</label>
                    <input type="text" id="plate_part3" name="plate_part3" class="form-control" maxlength="3" value="<?= htmlspecialchars($car['plate_part3']) ?>" required>
                </div>
                <div class="col-md-3">
                    <label for="plate_part4" class="form-label">کد شهر:</label>
                    <input type="text" id="plate_part4" name="plate_part4" class="form-control" maxlength="2" value="<?= htmlspecialchars($car['plate_part4']) ?>" required>
                </div>
            </div>
            <button type="submit" class="btn btn-primary mt-3">ذخیره تغییرات</button>
            <a href="edit_customer.php?customer_id=<?= $car['customer_id'] ?>" class="btn btn-secondary mt-3">بازگشت</a>
        </form>
    </div>
</body>
</html>