<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

// تابع ثبت لاگ
function logActivity($pdo, $admin_id, $action) {
    $ip_address = $_SERVER['REMOTE_ADDR']; // دریافت IP
    $stmt = $pdo->prepare("INSERT INTO activity_logs (admin_id, action, ip_address) VALUES (?, ?, ?)");
    $stmt->execute([$admin_id, $action, $ip_address]);
}

// بررسی دریافت شناسه مشتری
if (!isset($_GET['customer_id'])) {
    header("Location: admin_dashboard.php");
    exit();
}

$customer_id = intval($_GET['customer_id']);

// واکشی اطلاعات مشتری
$stmt = $pdo->prepare("SELECT * FROM customers WHERE id = ?");
$stmt->execute([$customer_id]);
$customer = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$customer) {
    echo "مشتری یافت نشد.";
    exit();
}

// ثبت لاگ مشاهده اطلاعات مشتری
logActivity($pdo, $_SESSION['admin_id'], "مشاهده اطلاعات مشتری با شناسه $customer_id");

// واکشی خودروهای ثبت‌شده برای مشتری
$stmt = $pdo->prepare("SELECT * FROM customer_cars WHERE customer_id = ?");
$stmt->execute([$customer_id]);
$cars = $stmt->fetchAll(PDO::FETCH_ASSOC);

// افزودن خودرو جدید
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_car'])) {
    $car_model = trim($_POST['car_model']);
    $plate_part1 = trim($_POST['plate_part1']);
    $plate_part2 = trim($_POST['plate_part2']);
    $plate_part3 = trim($_POST['plate_part3']);
    $plate_part4 = trim($_POST['plate_part4']);

    if (empty($car_model) || empty($plate_part1) || empty($plate_part2) || empty($plate_part3) || empty($plate_part4)) {
        $error_message = "لطفاً تمام فیلدها را پر کنید.";
    } else {
        try {
            $stmt = $pdo->prepare("INSERT INTO customer_cars (customer_id, car_model, plate_part1, plate_part2, plate_part3, plate_part4) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$customer_id, htmlspecialchars($car_model), htmlspecialchars($plate_part1), htmlspecialchars($plate_part2), htmlspecialchars($plate_part3), htmlspecialchars($plate_part4)]);

            // ثبت لاگ افزودن خودرو جدید
            logActivity($pdo, $_SESSION['admin_id'], "افزودن خودروی جدید ($car_model) برای مشتری با شناسه $customer_id");

            $success_message = "خودرو با موفقیت اضافه شد.";
            header("Refresh:0"); // بارگذاری مجدد صفحه
            exit();
        } catch (PDOException $e) {
            $error_message = "خطایی در ثبت خودرو رخ داد: " . $e->getMessage();
        }
    }
}
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_phone'])) {
    $new_phone_number = trim($_POST['phone_number']);

    // بررسی معتبر بودن شماره موبایل (مثلاً تعداد ارقام و شروع با 09)
    if (!preg_match('/^09\d{9}$/', $new_phone_number)) {
        echo "<div class='alert alert-danger'>شماره موبایل نامعتبر است.</div>";
    } else {
        try {
            $stmt = $pdo->prepare("UPDATE customers SET phone_number = ? WHERE id = ?");
            $stmt->execute([$new_phone_number, $customer_id]);

            // ثبت لاگ تغییر شماره موبایل
            logActivity($pdo, $_SESSION['admin_id'], "تغییر شماره موبایل مشتری با شناسه $customer_id به $new_phone_number");

            echo "<div class='alert alert-success'>شماره موبایل با موفقیت بروزرسانی شد.</div>";
            header("Refresh: 1"); // بارگذاری مجدد صفحه برای نمایش مقدار جدید
        } catch (PDOException $e) {
            echo "<div class='alert alert-danger'>خطایی رخ داد: " . $e->getMessage() . "</div>";
        }
    }
}


// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ویرایش مشتری</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Vazirmatn:wght@400;500;700&display=swap" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
    <style>
        /* تنظیمات کلی */
        body {
            font-family: 'Vazirmatn', sans-serif;
            background-color: #f8f9fa;
            color: #212529;
            direction: rtl;
            text-align: right;
            padding: 20px;
        }

        .container {
            max-width: 800px;
            margin: auto;
            background: #ffffff;
            padding: 30px;
            border-radius: 12px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            transition: transform 0.3s ease, box-shadow 0.3s ease;
        }

        .container:hover {
            transform: translateY(-5px);
            box-shadow: 0 6px 16px rgba(0, 0, 0, 0.15);
        }

        h1, h2 {
            color: #343a40;
            margin-bottom: 20px;
        }

        h1 {
            font-size: 28px;
            font-weight: bold;
            color: #1c0f69;
            text-align: center;
        }

        h2 {
            font-size: 22px;
            font-weight: 600;
        }

        /* فرم‌ها */
        form {
            margin-bottom: 30px;
        }

        .form-label {
            font-weight: bold;
            color: #495057;
            margin-bottom: 8px;
        }

        .form-control {
            padding: 10px;
            border: 1px solid #ced4da;
            border-radius: 6px;
            font-size: 14px;
            transition: border-color 0.3s ease, box-shadow 0.3s ease;
        }

        .form-control:focus {
            border-color: #80bdff;
            box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
        }

        /* دکمه‌ها */
        .btn {
            font-size: 14px;
            border-radius: 6px;
            padding: 10px 20px;
            transition: background-color 0.3s ease, transform 0.2s ease;
        }

        .btn-primary {
            background-color: #007bff;
            border-color: #007bff;
        }

        .btn-primary:hover {
            background-color: #0056b3;
            border-color: #004085;
            transform: translateY(-1px);
        }

        .btn-success {
            background-color: #28a745;
            border-color: #28a745;
        }

        .btn-success:hover {
            background-color: #218838;
            border-color: #1e7e34;
            transform: translateY(-1px);
        }

        .btn-secondary {
            background-color: #6c757d;
            border-color: #6c757d;
        }

        .btn-secondary:hover {
            background-color: #5a6268;
            border-color: #545b62;
            transform: translateY(-1px);
        }

        .btn-warning {
            background-color: #ffc107;
            border-color: #ffc107;
        }

        .btn-warning:hover {
            background-color: #e0a800;
            border-color: #d39e00;
            transform: translateY(-1px);
        }

        .btn-danger {
            background-color: #dc3545;
            border-color: #dc3545;
        }

        .btn-danger:hover {
            background-color: #c82333;
            border-color: #bd2130;
            transform: translateY(-1px);
        }

        /* جدول */
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
            background-color: #fff;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
        }

        table th, table td {
            border: 1px solid #dee2e6;
            padding: 12px;
            text-align: center;
        }

        table th {
            background-color: #007bff;
            color: #fff;
            font-weight: bold;
        }

        table tr:nth-child(even) {
            background-color: #f8f9fa;
        }

        table tr:hover {
            background-color: #e9ecef;
        }

        /* پیام‌ها */
        .alert {
            margin-top: 15px;
            padding: 12px;
            border-radius: 6px;
            font-size: 14px;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* واکنش‌گرایی */
        @media (max-width: 768px) {
            .container {
                padding: 20px;
            }

            h1 {
                font-size: 24px;
            }

            h2 {
                font-size: 20px;
            }

            .form-control {
                font-size: 12px;
            }

            .btn {
                font-size: 12px;
                padding: 8px 16px;
            }

            table th, table td {
                padding: 8px;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <h1> اطلاعات مشتری</h1>

        <!-- پیام‌های موفقیت و خطا -->
        <?php if (!empty($success_message)): ?>
            <div class="alert alert-success"><?= $success_message ?></div>
        <?php endif; ?>
        <?php if (!empty($error_message)): ?>
            <div class="alert alert-danger"><?= $error_message ?></div>
        <?php endif; ?>

        <!-- فرم ویرایش اطلاعات مشتری -->
        <form method="POST" class="mb-4">
            <div class="mb-3">
                <label for="full_name" class="form-label">نام و نام خانوادگی:</label>
                <input type="text" id="full_name" name="full_name" class="form-control" 
                       value="<?= htmlspecialchars($customer['full_name']) ?>" disabled>
            </div>
            <div class="mb-3">
                <label for="phone_number" class="form-label">شماره موبایل:</label>
                <input type="text" id="phone_number" name="phone_number" class="form-control" 
                       value="<?= htmlspecialchars($customer['phone_number']) ?>" disabled>
            </div>
        </form>
        <h2>ویرایش شماره موبایل مشتری</h2>
<form method="post">
    <div class="mb-3">
        <label for="phone_number" class="form-label">شماره موبایل</label>
        <input type="text" name="phone_number" id="phone_number" class="form-control" value="<?= htmlspecialchars($customer['phone_number']) ?>" required>
    </div>
    <button type="submit" name="update_phone" class="btn btn-primary">ثبت تغییرات</button>
</form>


        <!-- جدول نمایش خودروهای ثبت‌شده -->
        <h2>خودروهای ثبت‌شده</h2>
        <table>
            <thead>
                <tr>
                    <th>مدل خودرو</th>
                    <th>پلاک</th>
                    <th>عملیات</th>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($cars)): ?>
                    <?php foreach ($cars as $car): ?>
                        <tr>
                            <td><?= htmlspecialchars($car['car_model']) ?></td>
                            <td>
                                <?= htmlspecialchars($car['plate_part4']) ?> 
                                <?= htmlspecialchars($car['plate_part3']) ?> 
                                <?= htmlspecialchars($car['plate_part2']) ?> 
                                <?= htmlspecialchars($car['plate_part1']) ?>
                            </td>
                            <td>
                                <!-- دکمه ویرایش -->
                                <a href="edit_car.php?car_id=<?= $car['id'] ?>" class="btn btn-warning btn-sm">ویرایش</a>
                                <!-- دکمه حذف -->
                                <form method="POST" action="delete_car.php" style="display:inline;">
                                    <input type="hidden" name="car_id" value="<?= $car['id'] ?>">
                                    <input type="hidden" name="customer_id" value="<?= $customer['id'] ?>">
                                    <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('آیا از حذف این خودرو مطمئن هستید؟')">حذف</button>
                                </form>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="3">خودرویی برای این مشتری ثبت نشده است.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>

        <!-- فرم افزودن خودرو -->
        <h2 class="mt-4">افزودن خودروی جدید</h2>
        <form method="POST" class="mb-4">
            <div class="mb-3">
                <label for="car_model" class="form-label">مدل خودرو:</label>
                <input type="text" id="car_model" name="car_model" class="form-control" required>
            </div>
            <div class="row">
                <div class="col-md-3">
                    <label for="plate_part1" class="form-label">پ</label>
                    <input list="persian-letters" id="plate_part1" name="plate_part1" class="form-control" maxlength="2" required>
                    <datalist id="persian-letters">
                        <option value="11">
                        <option value="12">
                        <option value="13">
                        <option value="14">
                        <option value="15">
                        <option value="16">
                        <option value="17">
                        <option value="18">
                        <option value="19">
                        <option value="21">
                        <option value="22">
                        <option value="23">
                        <option value="24">
                        <option value="25">
                        <option value="26">
                        <option value="27">
                        <option value="28">
                        <option value="29">
                        <option value="31">
                        <option value="32">
                        <option value="33">
                        <option value="34">
                        <option value="35">
                        <option value="36">
                        <option value="37">
                        <option value="38">
                        <option value="39">
                        <option value="41">
                        <option value="42">
                        <option value="43">
                        <option value="44">
                        <option value="45">
                        <option value="46">
                        <option value="47">
                        <option value="48">
                        <option value="49">
                        <option value="51">
                        <option value="52">
                        <option value="53">
                        <option value="54">
                        <option value="55">
                        <option value="56">
                        <option value="57">
                        <option value="58">
                        <option value="59">
                        <option value="61">
                        <option value="62">
                        <option value="63">
                        <option value="64">
                        <option value="65">
                        <option value="66">
                        <option value="67">
                        <option value="68">
                        <option value="69">
                        <option value="71">
                        <option value="72">
                        <option value="73">
                        <option value="74">
                        <option value="75">
                        <option value="76">
                        <option value="77">
                        <option value="78">
                        <option value="79">
                        <option value="81">
                        <option value="82">
                        <option value="83">
                        <option value="84">
                        <option value="85">
                        <option value="86">
                        <option value="87">
                        <option value="88">
                        <option value="89">
                        <option value="91">
                        <option value="92">
                        <option value="93">
                        <option value="94">
                        <option value="95">
                        <option value="96">
                        <option value="97">
                        <option value="98">
                        <option value="99">
                    </datalist>
                </div>
                <div class="col-md-3">
                    <label for="plate_part2" class="form-label">ل:</label>
                    <select id="plate_part2" name="plate_part2" class="form-control select2" required>
                        <option value="">لطفاً یک حرف انتخاب کنید</option>
                        <option value="الف">الف</option>
                        <option value="ب">ب</option>
                        <option value="پ">پ</option>
                        <option value="ت">ت</option>
                        <option value="ث">ث</option>
                        <option value="ج">ج</option>
                        <option value="چ">چ</option>
                        <option value="ح">ح</option>
                        <option value="خ">خ</option>
                        <option value="د">د</option>
                        <option value="ذ">ذ</option>
                        <option value="ر">ر</option>
                        <option value="ز">ز</option>
                        <option value="ژ">ژ</option>
                        <option value="س">س</option>
                        <option value="ش">ش</option>
                        <option value="ص">ص</option>
                        <option value="ض">ض</option>
                        <option value="ط">ط</option>
                        <option value="ظ">ظ</option>
                        <option value="ع">ع</option>
                        <option value="غ">غ</option>
                        <option value="ف">ف</option>
                        <option value="ق">ق</option>
                        <option value="ک">ک</option>
                        <option value="گ">گ</option>
                        <option value="ل">ل</option>
                        <option value="م">م</option>
                        <option value="ن">ن</option>
                        <option value="و">و</option>
                        <option value="ه">ه</option>
                        <option value="ی">ی</option>
                    </select>
                </div>
                <div class="col-md-3">
                    <label for="plate_part3" class="form-label"> ا:</label>
                    <input type="text" id="plate_part3" name="plate_part3" class="form-control" maxlength="3" required>
                </div>
                <div class="col-md-3">
                    <label for="plate_part4" class="form-label"> ک:</label>
                    <input type="text" id="plate_part4" name="plate_part4" class="form-control" maxlength="2" required>
                </div>
            </div>
            <button type="submit" name="add_car" class="btn btn-success mt-3">افزودن خودرو</button>
        </form>

        <a href="admin_dashboard" class="btn btn-secondary">بازگشت به داشبورد</a>
    </div>

    <script>
        $(document).ready(function() {
            $('.select2').select2();
        });
    </script>
</body>
</html>
