<?php
require '../../../config/config.php';
session_start();

$error_message = '';

// تابع ثبت لاگ
function logActivity($pdo, $admin_id, $action) {
    $ip_address = $_SERVER['REMOTE_ADDR']; // دریافت IP
    $stmt = $pdo->prepare("INSERT INTO activity_logs (admin_id, action, ip_address) VALUES (?, ?, ?)");
    $stmt->execute([$admin_id, $action, $ip_address]);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // پاکسازی ورودی‌ها
    $username = trim($_POST['username']);
    $password = trim($_POST['password']);

    try {
        // واکشی مدیر با نام کاربری داده شده
        $stmt = $pdo->prepare("SELECT * FROM admins WHERE username = ?");
        $stmt->execute([$username]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);

        // بررسی نام کاربری و رمز عبور
        if ($user && password_verify($password, $user['password'])) {
            // مقداردهی سشن
            $_SESSION['admin_logged_in'] = true;
            $_SESSION['admin_id'] = $user['id']; // ذخیره شناسه مدیر
            $_SESSION['admin_name'] = $user['name']; // ذخیره نام مدیر (اختیاری)

            // ثبت لاگ ورود موفق
            logActivity($pdo, $user['id'], "ورود موفق به سامانه");

            // هدایت به داشبورد
            header("Location: admin_dashboard");
            exit();
        } else {
            // ثبت لاگ تلاش ناموفق
            logActivity($pdo, null, "تلاش ناموفق برای ورود (نام کاربری: $username)");

            $error_message = "نام کاربری یا رمز عبور اشتباه است.";
        }
    } catch (PDOException $e) {
        $error_message = "خطایی در فرآیند ورود رخ داد: " . $e->getMessage();
    }
}
?>

<html lang="fa">
<head>
    <meta charset="utf-8"/>
    <meta content="width=device-width, initial-scale=1.0" name="viewport"/>
    <title>سامانه مدیریت مشتریان</title>
    <link href="manifest.json" rel="manifest"/>
    <link href="../../../images/download.ico" rel="icon" type="image/x-icon"/>
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet"/>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet"/>
    <script src="https://cdn.tailwindcss.com"></script>
    <script>
        let deferredPrompt;

        window.addEventListener("beforeinstallprompt", (event) => {
            event.preventDefault();
            deferredPrompt = event;
            document.getElementById("installBanner").classList.remove("hidden");
        });

        function installApp() {
            if (deferredPrompt) {
                deferredPrompt.prompt();
                deferredPrompt.userChoice.then((choiceResult) => {
                    if (choiceResult.outcome === "accepted") {
                        console.log("User accepted the PWA installation");
                    } else {
                        console.log("User dismissed the PWA installation");
                    }
                    deferredPrompt = null;
                    document.getElementById("installBanner").classList.add("hidden");
                });
            }
        }
    </script>
</head>
<body class="bg-gradient-to-r from-blue-500 to-blue-700 flex items-center justify-center min-h-screen">
    
    <!-- پیام نصب برنامه -->
    <div id="installBanner" class="hidden fixed bottom-5 left-1/2 transform -translate-x-1/2 bg-white p-4 rounded-lg shadow-lg flex items-center space-x-4">
        <p class="text-gray-700">برای نصب برنامه روی دکمه زیر کلیک کنید:</p>
        <button onclick="installApp()" class="bg-blue-600 text-white px-4 py-2 rounded-lg shadow-md hover:bg-blue-700 transition duration-300">نصب برنامه</button>
    </div>

    <div class="bg-white p-8 rounded-2xl shadow-2xl w-full max-w-md">
        <div class="flex justify-center mb-6">
            <img alt="تصویر مدیریت اتوسرویس" class="rounded-lg" height="200" src="../../../images/logo1.png" width="300"/>
        </div>

        <?php if (isset($error_message)): ?>
            
        <?php endif; ?>

        <form class="space-y-4" method="POST">
            <div>
                <label class="block text-right mb-1 font-medium text-gray-700" for="username">نام کاربری:</label>
                <div class="relative">
                    <input class="w-full px-4 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 transition-all duration-200 shadow-sm" id="username" name="username" required="" type="text"/>
                    <i class="fas fa-user absolute right-4 top-3 text-gray-400"></i>
                </div>
            </div>
            <div>
                <label class="block text-right mb-1 font-medium text-gray-700" for="password">رمز عبور:</label>
                <div class="relative">
                    <input class="w-full px-4 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 transition-all duration-200 shadow-sm" id="password" name="password" required="" type="password"/>
                    <i class="fas fa-lock absolute right-4 top-3 text-gray-400"></i>
                </div>
            </div>
            <button class="w-full bg-blue-600 text-white py-2 rounded-lg hover:bg-blue-700 transition duration-300 font-semibold shadow-md" type="submit">ورود</button>
        </form>

        <div class="text-center mt-4">
            <a class="text-blue-500 hover:underline" href="#">فراموشی رمز عبور</a>
        </div>

        <p class="text-center text-gray-500 mt-4 text-sm">نسخه 1.1.0</p>
    </div>
</body>
</html>

