<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

// واکشی لاگ‌های فعالیت مدیران
try {
    $stmt = $pdo->query("
        SELECT l.id, a.username, l.action, l.ip_address, l.created_at 
        FROM activity_logs l
        JOIN admins a ON l.admin_id = a.id
        ORDER BY l.created_at DESC
    ");
    $logs = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("خطایی در واکشی داده‌ها رخ داد: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>گزارش فعالیت مدیران</title>
    <link rel="stylesheet" href="../../../public/css/logs.css">
    <style>
        body {
            font-family: 'Yekan', sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f4f4f9;
            direction: rtl;
        }
        .container {
            max-width: 1200px;
            margin: 20px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }
        h1 {
            text-align: center;
            color: #333;
            margin-bottom: 20px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }
        table th, table td {
            text-align: left;
            padding: 12px;
            border: 1px solid #ddd;
        }
        table th {
            background-color: #f7f7f7;
            color: #333;
        }
        table tr:nth-child(even) {
            background-color: #f9f9f9;
        }
        .btn-back {
            display: inline-block;
            padding: 10px 20px;
            background-color: #007bff;
            color: #fff;
            text-decoration: none;
            border-radius: 4px;
        }
        .btn-back:hover {
            background-color: #0056b3;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>گزارش فعالیت مدیران</h1>
        
        <?php if (count($logs) > 0): ?>
            <table>
                <thead>
                    <tr>
                        <th>#</th>
                        <th>نام کاربری مدیر</th>
                        <th>عملیات</th>
                        <th>آدرس IP</th>
                        <th>زمان</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($logs as $log): ?>
                        <tr>
                            <td><?= htmlspecialchars($log['id']) ?></td>
                            <td><?= htmlspecialchars($log['username']) ?></td>
                            <td><?= htmlspecialchars($log['action']) ?></td>
                            <td><?= htmlspecialchars($log['ip_address']) ?></td>
                            <td><?= htmlspecialchars($log['created_at']) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <p>هیچ فعالیتی ثبت نشده است.</p>
        <?php endif; ?>
        
        <a href="admin_dashboard.php" class="btn-back">بازگشت به داشبورد</a>
    </div>
</body>
</html>
