<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';

session_start();

if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

$error_message = '';
$report_data = [];
$search_query = '';
$start_date = '';
$end_date = '';
$plate_part3 = '';
$total_amount_received = 0;

function persianToEnglish($number) {
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    return str_replace($persian, $english, $number);
}

function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $search_query = trim($_GET['customer_name'] ?? '');
    $start_date = trim($_GET['start_date'] ?? '');
    $end_date = trim($_GET['end_date'] ?? '');
    $plate_part3 = trim($_GET['plate_part3'] ?? '');

    try {
        $query = "
            SELECT s.*, c.full_name, c.phone_number, cc.plate_part3,
                   GROUP_CONCAT(CONCAT(si.item_name, ': ', si.action_type) SEPARATOR ' | ') AS service_items 
            FROM services s 
            JOIN customer_cars cc ON s.car_id = cc.id 
            JOIN customers c ON cc.customer_id = c.id 
            LEFT JOIN service_items si ON s.id = si.service_id 
        ";

        $conditions = [];
        $params = [];

        if (!empty($search_query)) {
            $conditions[] = "c.full_name LIKE :search_query";
            $params[':search_query'] = "%$search_query%";
        }

        if (!empty($plate_part3)) {
            $plate_part3_english = persianToEnglish($plate_part3);
            $plate_part3_persian = englishToPersian($plate_part3);

            $conditions[] = "(cc.plate_part3 LIKE :plate_part3_english OR cc.plate_part3 LIKE :plate_part3_persian)";
            $params[':plate_part3_english'] = "%$plate_part3_english%";
            $params[':plate_part3_persian'] = "%$plate_part3_persian%";
        }

        if (!empty($start_date) && !empty($end_date)) {
            list($start_year, $start_month, $start_day) = explode('-', $start_date);
            list($end_year, $end_month, $end_day) = explode('-', $end_date);

            $gregorian_start_date = implode('-', jalali_to_gregorian($start_year, $start_month, $start_day));
            $gregorian_end_date = implode('-', jalali_to_gregorian($end_year, $end_month, $end_day));

            $conditions[] = "s.service_date BETWEEN :start_date AND :end_date";
            $params[':start_date'] = $gregorian_start_date;
            $params[':end_date'] = $gregorian_end_date;
        }

        if (!empty($conditions)) {
            $query .= " WHERE " . implode(" AND ", $conditions);
        }

        $query .= " GROUP BY s.id ORDER BY s.service_date ASC";

        $stmt = $pdo->prepare($query);
        $stmt->execute($params);
        $report_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

        foreach ($report_data as $service) {
            $total_amount_received += $service['amount_received'];
        }

        if (empty($report_data)) {
            $error_message = "هیچ سرویسی یافت نشد.";
        }
    } catch (PDOException $e) {
        $error_message = "خطایی در واکشی داده‌ها رخ داد: " . $e->getMessage();
    }
}



?>

<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>گزارش‌گیری از سرویس‌ها</title>
    <link href="https://cdn.jsdelivr.net/gh/rastikerdar/vazir-font@v30.1.0/dist/font-face.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Vazir', sans-serif;
        }
    </style>
</head>
<body class="bg-gray-100 text-gray-800">

    <!-- هدر -->
    <header class="bg-gray-600 text-white py-4">
        <div class="container mx-auto px-4">
            <h1 class="text-2xl font-bold">گزارش‌گیری از سرویس‌ها</h1>
        </div>
    </header>

    <!-- بخش اصلی -->
    <main class="container mx-auto px-4 py-8">
        <!-- پیام خطا -->
        <?php if ($error_message): ?>
            <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded mb-4">
                <?= $error_message ?>
            </div>
        <?php endif; ?>

        <!-- فرم جستجو -->
        <form method="GET" action="" class="bg-white p-6 rounded-lg shadow-md mb-6">
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-4">
                <div>
                    <label for="customer_name" class="block text-sm font-medium text-gray-700">نام مشتری:</label>
                    <input type="text" name="customer_name" id="customer_name" placeholder="مثال: حسن رضایی"
                           class="mt-1 block w-full p-2 border border-gray-300 rounded-md focus:outline-none focus:border-blue-500"
                           value="<?= htmlspecialchars($search_query) ?>">
                </div>
                <div>
                    <label for="plate_part3" class="block text-sm font-medium text-gray-700">شماره پلاک:</label>
                    <input type="text" name="plate_part3" id="plate_part3" placeholder="مثال: 12الف345"
                           class="mt-1 block w-full p-2 border border-gray-300 rounded-md focus:outline-none focus:border-blue-500"
                           value="<?= htmlspecialchars($plate_part3) ?>">
                </div>
                <div>
                    <label for="start_date" class="block text-sm font-medium text-gray-700">تاریخ شروع:</label>
                    <input type="text" name="start_date" id="start_date" placeholder="مثال: 1401-01-01"
                           class="mt-1 block w-full p-2 border border-gray-300 rounded-md focus:outline-none focus:border-blue-500"
                           value="<?= htmlspecialchars($start_date) ?>">
                </div>
                <div>
                    <label for="end_date" class="block text-sm font-medium text-gray-700">تاریخ پایان:</label>
                    <input type="text" name="end_date" id="end_date" placeholder="مثال: 1401-12-29"
                           class="mt-1 block w-full p-2 border border-gray-300 rounded-md focus:outline-none focus:border-blue-500"
                           value="<?= htmlspecialchars($end_date) ?>">
                </div>
            </div>
            <div class="mt-4 text-center">
                <button type="submit" class="bg-blue-500 text-white px-6 py-2 rounded-lg hover:bg-blue-600 transition-colors">
                    دریافت گزارش
                </button>
            </div>
        </form>

        <?php if (!empty($report_data)): ?>
            <!-- جدول گزارش -->
            <div class="bg-white rounded-lg shadow-md overflow-x-auto">
                <table class="min-w-full">
                    <thead class="bg-gray-600 text-white">
                        <tr>
                            <th class="px-6 py-3 text-right">تاریخ سرویس</th>
                            <th class="px-6 py-3 text-right">نوع روغن</th>
                            <th class="px-6 py-3 text-right">کیلومتر فعلی</th>
                            <th class="px-6 py-3 text-right">کیلومتر بعدی</th>
                            <th class="px-6 py-3 text-right">نام مشتری</th>
                            <th class="px-6 py-3 text-right">مبلغ دریافتی</th>
                        </tr>
                    </thead>
                    <tbody class="divide-y divide-gray-200">
                        <?php foreach ($report_data as $service): ?>
                            <tr class="hover:bg-gray-50 transition-colors">
                                <td class="px-6 py-4">
                                    <a href="service_items.php?service_id=<?= $service['id'] ?>" class="text-blue-500 hover:underline">
                                        <?php
                                        if (!empty($service['service_date']) && $service['service_date'] !== '0000-00-00') {
                                            list($gy, $gm, $gd) = explode('-', $service['service_date']);
                                            list($jy, $jm, $jd) = gregorian_to_jalali($gy, $gm, $gd);
                                            echo englishToPersian("$jy/$jm/$jd");
                                        } else {
                                            echo "نامشخص";
                                        }
                                        ?>
                                    </a>
                                </td>
                                <td class="px-6 py-4"><?= htmlspecialchars($service['oil_type']) ?></td>
                                <td class="px-6 py-4"><?= englishToPersian(htmlspecialchars($service['kilometer'])) ?></td>
                                <td class="px-6 py-4"><?= englishToPersian(htmlspecialchars($service['next_kilometer'])) ?></td>
                                <td class="px-6 py-4"><?= htmlspecialchars($service['full_name']) ?></td>
                                <td class="px-6 py-4"><?= englishToPersian(number_format($service['amount_received'], 0, '.', ',')) ?> تومان</td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- جمع کل مبالغ دریافتی -->
            <div class="mt-6 bg-white p-4 rounded-lg shadow-md">
                <p class="text-lg font-semibold">
                    <span class="text-gray-700">جمع کل مبالغ دریافتی:</span>
                    <span class="text-blue-500"><?= englishToPersian(number_format($total_amount_received, 0, '.', ',')) ?> تومان</span>
                </p>
            </div>
        <?php endif; ?>

        <!-- دکمه بازگشت -->
        <div class="mt-6 text-center">
            <a href="admin_dashboard" class="inline-block bg-gray-500 text-white px-6 py-2 rounded-lg hover:bg-gray-600 transition-colors">
                بازگشت به داشبورد
            </a>
        </div>
    </main>

</body>
</html>

