<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی شناسه سرویس
if (!isset($_GET['service_id'])) {
    die("شناسه سرویس نامعتبر است.");
}

$service_id = intval($_GET['service_id']);

// بررسی لاگین مدیر
if (!isset($_SESSION['admin_logged_in'])) {
    header("Location: index.php");
    exit();
}

// تابع ثبت لاگ
function logActivity($pdo, $admin_id, $action) {
    $ip_address = $_SERVER['REMOTE_ADDR']; // دریافت IP
    $stmt = $pdo->prepare("INSERT INTO activity_logs (admin_id, action, ip_address) VALUES (?, ?, ?)");
    $stmt->execute([$admin_id, $action, $ip_address]);
}

try {
    // واکشی اطلاعات سرویس، مشتری و خودرو
    $stmt = $pdo->prepare(
        "SELECT s.*, c.full_name, cc.car_model, cc.plate_part4, cc.plate_part3, cc.plate_part2, cc.plate_part1, 
                GROUP_CONCAT(CONCAT(si.item_name, ':', si.action_type) SEPARATOR ',') AS service_items 
         FROM services s 
         LEFT JOIN service_items si ON s.id = si.service_id 
         JOIN customer_cars cc ON s.car_id = cc.id 
         JOIN customers c ON cc.customer_id = c.id 
         WHERE s.id = ? 
         GROUP BY s.id"
    );
    $stmt->execute([$service_id]);
    $service = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$service) {
        die("سرویس یافت نشد.");
    }

    // ثبت لاگ بازدید مدیر از سرویس
    logActivity($pdo, $_SESSION['admin_id'], "بازدید از جزئیات سرویس با شناسه $service_id");

} catch (PDOException $e) {
    die("خطایی رخ داد: " . $e->getMessage());
}

// تبدیل آیتم‌های سرویس به آرایه
function parseServiceItems($service_items) {
    $items = explode(',', $service_items);
    $parsed_items = [];
    foreach ($items as $item) {
        list($name, $action) = explode(':', $item);
        $parsed_items[$name] = $action;
    }
    return $parsed_items;
}

// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

$items = parseServiceItems($service['service_items']);
?>

<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>کارت سرویس</title>
    <link href="https://cdn.jsdelivr.net/gh/rastikerdar/vazir-font@v30.1.0/dist/font-face.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Vazir', sans-serif;
        }
    </style>
</head>
<body class="bg-gray-100 text-gray-800">

    <!-- هدر -->
    <header class="bg-gray-600 text-white py-4">
        <div class="container mx-auto px-4">
            <h1 class="text-2xl font-bold">کارت سرویس</h1>
        </div>
    </header>

    <!-- بخش اصلی -->
    <main class="container mx-auto px-4 py-8">
        <!-- اطلاعات سرویس -->
        <div class="bg-white rounded-lg shadow-md p-6 mb-6">
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <p class="text-gray-700"><strong>نام مشتری:</strong> <?= htmlspecialchars($service['full_name']) ?></p>
                    <p class="text-gray-700"><strong>مدل خودرو:</strong> <?= htmlspecialchars($service['car_model']) ?></p>
                    <p class="text-gray-700"><strong>پلاک:</strong> <?= htmlspecialchars($service['plate_part4']) ?> <?= htmlspecialchars($service['plate_part3']) ?> <?= htmlspecialchars($service['plate_part2']) ?> <?= htmlspecialchars($service['plate_part1']) ?></p>
                </div>
                <div>
                    <p class="text-gray-700"><strong>تاریخ سرویس:</strong> 
                        <?php
                        if (!empty($service['service_date']) && $service['service_date'] !== '0000-00-00') {
                            list($gy, $gm, $gd) = explode('-', $service['service_date']);
                            list($jy, $jm, $jd) = gregorian_to_jalali($gy, $gm, $gd);
                            echo "$jy/$jm/$jd";
                        } else {
                            echo "نامشخص";
                        }
                        ?>
                    </p>
                    <p class="text-gray-700"><strong>نوع روغن:</strong> <?= htmlspecialchars($service['oil_type']) ?></p>
                    <p class="text-gray-700"><strong>مبلغ پرداختی:</strong> <?= number_format($service['amount_received'] ?? 0) ?> تومان</p>
                </div>
            </div>
        </div>

        <!-- جدول آیتم‌های سرویس -->
        <div class="bg-white rounded-lg shadow-md overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-600 text-white">
                    <tr>
                        <th class="px-6 py-3 text-right">نام سرویس</th>
                        <th class="px-6 py-3 text-right">تعویض</th>
                        <th class="px-6 py-3 text-right">بازدید</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-200">
                    <?php foreach ($items as $name => $action): ?>
                        <tr class="hover:bg-gray-50 transition-colors">
                            <td class="px-6 py-4"><?= htmlspecialchars($name) ?></td>
                            <td class="px-6 py-4"><?= $action === 'تعویض' ? '✔️' : '---' ?></td>
                            <td class="px-6 py-4"><?= $action === 'بازدید' ? '✔️' : '---' ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- دکمه‌های بازگشت و چاپ -->
        <div class="mt-6 flex justify-center space-x-4">
            <a href="javascript:history.back()" class="bg-gray-500 text-white px-6 py-2 rounded-lg hover:bg-gray-600 transition-colors">بازگشت</a>
            <a href="javascript:window.print()" class="bg-blue-500 text-white px-6 py-2 rounded-lg hover:bg-blue-600 transition-colors">چاپ</a>
        </div>
    </main>

</body>
</html>

