<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مشتری
if (!isset($_SESSION['customer_logged_in'])) {
    header("Location: customer_login.php");
    exit();
}

$customer_id = $_SESSION['customer_id'];
$error_message = '';
$success_message = '';

try {
    // واکشی خودروهای ثبت‌شده برای مشتری
    $stmt = $pdo->prepare("SELECT * FROM customer_cars WHERE customer_id = ?");
    $stmt->execute([$customer_id]);
    $cars = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("خطایی رخ داد: " . $e->getMessage());
}

// دریافت اطلاعات آخرین سرویس و تاریخ مراجعه بعدی
$services = [];
foreach ($cars as $car) {
    $stmt = $pdo->prepare("SELECT service_date, next_service_date FROM services WHERE car_id = ? ORDER BY service_date DESC LIMIT 1");
    $stmt->execute([$car['id']]);
    $service = $stmt->fetch(PDO::FETCH_ASSOC);
    $services[$car['id']] = $service ? $service : ["service_date" => "نامشخص", "next_service_date" => "نامشخص"];
}

// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

// محاسبه درصد نوار پیشرفت
function calculateProgress($last_service, $next_service) {
    if ($last_service == "نامشخص" || $next_service == "نامشخص") {
        return 0;
    }
    $last = strtotime($last_service);
    $next = strtotime($next_service);
    $now = time();
    if ($now >= $next) return 100;
    return round((($now - $last) / ($next - $last)) * 100);
}
?>
<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>داشبورد مشتری</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- فونت‌های فارسی -->
    <link href="https://cdn.fontcdn.ir/Font/Persian/Vazir/Vazirmatn.css" rel="stylesheet">
    <style>
        body {
            font-family: Vazirmatn, sans-serif;
        }
        .dark-mode {
            background-color: #1a202c;
            color: #cbd5e0;
        }
        .dark-mode .card {
            background-color: #2d3748;
            color: #cbd5e0;
        }
        .dark-mode .btn-dark {
            background-color: #4a5568;
            border-color: #4a5568;
        }
        .dark-mode .progress {
            background-color: #4a5568;
        }
        .dark-mode .alert {
            background-color: #2d3748;
            border-color: #4a5568;
            color: #cbd5e0;
        }
    </style>
</head>
<body class="bg-light text-dark rtl">
    <div class="container py-5">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1 class="h3 fw-bold">داشبورد مشتری</h1>
            <button onclick="toggleDarkMode()" class="btn btn-dark">حالت شب</button>
        </div>

        <?php if ($success_message): ?>
            <div class="alert alert-success"> <?= $success_message ?> </div>
        <?php endif; ?>
        <?php if ($error_message): ?>
            <div class="alert alert-danger"> <?= $error_message ?> </div>
        <?php endif; ?>

        <h2 class="h4 mb-4">خودروهای ثبت‌شده شما:</h2>
        <div class="row row-cols-1 row-cols-md-2 row-cols-lg-3 g-4">
            <?php foreach ($cars as $car): ?>
                <?php 
                $progress = calculateProgress($services[$car['id']]['service_date'], $services[$car['id']]['next_service_date']);
                ?>
                <div class="col">
                    <div class="card shadow-sm h-100">
                        <img src="../../../images/car12_prev_ui.png" alt="خودرو" class="card-img-top w-50 mx-auto mt-3">
                        <div class="card-body text-center">
                            <h5 class="card-title"> <?= htmlspecialchars($car['car_model']) ?> </h5>
                            <p class="card-text">
                                <span class="badge bg-secondary"><?= htmlspecialchars($car['plate_part4']) ?></span>
                                <span class="badge bg-secondary"><?= htmlspecialchars($car['plate_part3']) ?></span>
                                <span class="badge bg-secondary"><?= htmlspecialchars($car['plate_part2']) ?></span>
                                <span class="badge bg-secondary"><?= htmlspecialchars($car['plate_part1']) ?></span>
                            </p>
                            <p class="text-muted">آخرین سرویس: <?= ($services[$car['id']]['service_date'] != "نامشخص") ? jdate('Y/m/d', strtotime($services[$car['id']]['service_date'])) : "نامشخص"; ?> </p>
                            <p class="text-muted">مراجعه بعدی(تقریبی): <?= ($services[$car['id']]['next_service_date'] != "نامشخص") ? jdate('Y/m/d', strtotime($services[$car['id']]['next_service_date'])) : "نامشخص"; ?> </p>
                            <div class="progress mt-3">
                                <div class="progress-bar" role="progressbar" style="width: <?= $progress ?>%;" aria-valuenow="<?= $progress ?>" aria-valuemin="0" aria-valuemax="100">
                                    <?= englishToPersian($progress) ?>%
                                </div>
                            </div>
                            <a href="view_services?car_id=<?= $car['id'] ?>" class="btn btn-primary mt-3">مشاهده سرویس‌ها</a>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>

        <a href="logout" class="btn btn-danger d-block mx-auto mt-5">
            خروج
        </a>
    </div>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function toggleDarkMode() {
            document.body.classList.toggle('dark-mode');
            localStorage.setItem('darkMode', document.body.classList.contains('dark-mode'));
        }

        window.onload = function() {
            if (localStorage.getItem('darkMode') === 'true') {
                document.body.classList.add('dark-mode');
            }
        }
    </script>
</body>
</html>