<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی شناسه سرویس
if (!isset($_GET['service_id'])) {
    die("شناسه سرویس نامعتبر است.");
}

$service_id = intval($_GET['service_id']);

try {
    // واکشی اطلاعات سرویس، مشتری و خودرو
    $stmt = $pdo->prepare(
        "SELECT s.*, c.full_name, cc.car_model, cc.plate_part4, cc.plate_part3, cc.plate_part2, cc.plate_part1, 
                GROUP_CONCAT(CONCAT(si.item_name, ':', si.action_type) SEPARATOR ',') AS service_items 
         FROM services s 
         LEFT JOIN service_items si ON s.id = si.service_id 
         JOIN customer_cars cc ON s.car_id = cc.id 
         JOIN customers c ON cc.customer_id = c.id 
         WHERE s.id = ? 
         GROUP BY s.id"
    );
    $stmt->execute([$service_id]);
    $service = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$service) {
        die("سرویس یافت نشد.");
    }
} catch (PDOException $e) {
    die("خطایی رخ داد: " . $e->getMessage());
}

// تبدیل آیتم‌های سرویس به آرایه
function parseServiceItems($service_items) {
    $items = explode(',', $service_items);
    $parsed_items = [];
    foreach ($items as $item) {
        list($name, $action) = explode(':', $item);
        $parsed_items[$name] = $action;
    }
    return $parsed_items;
}

// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}

$items = parseServiceItems($service['service_items']);
?>
<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>کارت سرویس</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- فونت Vazir -->
    <link href="https://cdn.fontcdn.ir/Font/Persian/Vazir/Vazirmatn.css" rel="stylesheet">
    <style>
        body {
            font-family: Vazirmatn, sans-serif;
            background-color: #f8f9fa;
        }
        .service-card {
            background-color: #fff;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin: 20px auto;
            max-width: 800px;
        }
        .service-card h1 {
            font-size: 24px;
            font-weight: bold;
            margin-bottom: 20px;
            text-align: center;
        }
        .service-card .details {
            display: flex;
            justify-content: space-between;
            margin-bottom: 20px;
        }
        .service-card .details .column {
            flex: 1;
            padding: 0 10px;
        }
        .service-card .details p {
            margin: 5px 0;
        }
        .service-card table {
            width: 100%;
            margin-bottom: 20px;
        }
        .service-card table th,
        .service-card table td {
            text-align: center;
            padding: 10px;
        }
        .service-card table th {
            background-color: #f8f9fa;
        }
        .service-card .btn-return,
        .service-card .btn-print {
            display: inline-block;
            margin: 5px;
            padding: 10px 20px;
            border-radius: 5px;
            text-decoration: none;
            color: #fff;
        }
        .service-card .btn-return {
            background-color: #6c757d;
        }
        .service-card .btn-print {
            background-color: #007bff;
        }
        .service-card .btn-return:hover {
            background-color: #5a6268;
        }
        .service-card .btn-print:hover {
            background-color: #0056b3;
        }
    </style>
</head>
<body>
    <div class="service-card">
        <h1>کارت سرویس</h1>
        <div class="details">
            <div class="column">
                <p><strong>نام مشتری:</strong> <?= htmlspecialchars($service['full_name']) ?></p>
                <p><strong>مدل خودرو:</strong> <?= htmlspecialchars($service['car_model']) ?></p>
                <p><strong>پلاک: </strong><?= htmlspecialchars($service['plate_part4']) ?> <?= htmlspecialchars($service['plate_part3']) ?> <?= htmlspecialchars($service['plate_part2']) ?> <?= htmlspecialchars($service['plate_part1']) ?></p>
            </div>
            <div class="column">
                <p><strong>تاریخ سرویس:</strong> 
                    <?php
                    if (!empty($service['service_date']) && $service['service_date'] !== '0000-00-00') {
                        list($gy, $gm, $gd) = explode('-', $service['service_date']);
                        list($jy, $jm, $jd) = gregorian_to_jalali($gy, $gm, $gd);
                        echo "$jy/$jm/$jd";
                    } else {
                        echo "نامشخص";
                    }
                    ?>
                </p>
                <p><strong>نوع روغن:</strong> <?= htmlspecialchars($service['oil_type']) ?></p>
                <p><strong>مبلغ پرداختی:</strong> <?= number_format($service['amount_received'] ?? 0) ?></p>
            </div>
        </div>
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>نام سرویس</th>
                    <th>تعویض</th>
                    <th>بازدید</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($items as $name => $action): ?>
                    <tr>
                        <td><?= htmlspecialchars($name) ?></td>
                        <td><?= $action === 'تعویض' ? '✔️' : '---' ?></td>
                        <td><?= $action === 'بازدید' ? '✔️' : '---' ?></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        <div class="text-center">
            <a href="javascript:history.back()" class="btn-return">بازگشت</a>
            <a href="javascript:window.print()" class="btn-print">چاپ</a>
        </div>
    </div>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>