<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مشتری
if (!isset($_SESSION['customer_logged_in'])) {
    header("Location: index.php");
    exit();
}

if (!isset($_GET['car_id'])) {
    die("شناسه خودرو نامعتبر است.");
}

$car_id = intval($_GET['car_id']);

try {
    // واکشی سرویس‌ها و آیتم‌های مرتبط برای خودرو
    $stmt = $pdo->prepare(
        "SELECT s.*, 
                GROUP_CONCAT(CONCAT(si.item_name, ':', si.action_type) SEPARATOR ',') AS service_items 
         FROM services s 
         LEFT JOIN service_items si ON s.id = si.service_id 
         WHERE s.car_id = ? 
         GROUP BY s.id 
         ORDER BY s.service_date DESC"
    );
    $stmt->execute([$car_id]);
    $services = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("خطایی رخ داد: " . $e->getMessage());
}

// تابع برای تبدیل اعداد به فارسی
function convertToPersianNumbers($input) {
    $english_numbers = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian_numbers = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english_numbers, $persian_numbers, $input);
}

// تابع برای تبدیل آیتم‌های سرویس به آرایه
function parseServiceItems($service_items) {
    $items = explode(',', $service_items);
    $parsed_items = [];
    foreach ($items as $item) {
        list($name, $action) = explode(':', $item);
        $parsed_items[$name] = $action;
    }
    return $parsed_items;
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>مشاهده سرویس‌ها</title>
    <link rel="stylesheet" href="view.css">
    <style>
        body {
            font-family: 'Yekan', sans-serif;
            background-color: #f9f9f9;
            direction: rtl;
        }

        .services-container {
            width: 90%;
            margin: 20px auto;
            padding: 20px;
            background-color: #ffffff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        h1 {
            text-align: center;
            color: #333;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }

        th, td {
            padding: 12px;
            text-align: center;
            border: 1px solid #ddd;
        }

        th {
            background-color: #f4f4f4;
            font-weight: bold;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        a.service-link {
            text-decoration: none;
            color: #007bff;
            font-weight: bold;
        }

        a.service-link:hover {
            text-decoration: underline;
        }

        .btn-return {
            display: block;
            text-align: center;
            margin: 20px auto;
            padding: 10px 20px;
            background-color: #28a745;
            color: white;
            text-decoration: none;
            border-radius: 5px;
            width: 200px;
        }

        .btn-return:hover {
            background-color: #218838;
        }
    </style>
</head>
<body>
    <div class="services-container">
        <h1>سرویس‌های ثبت‌شده برای خودرو</h1>

        <?php if (empty($services)): ?>
            <p>هیچ سرویسی برای این خودرو ثبت نشده است.</p>
        <?php else: ?>
            <table>
                <thead>
                    <tr>
                        <th>تاریخ سرویس</th>
                        <th>نوع روغن</th>
                        <th>کیلومتر بعدی</th>
                        <th>یادداشت‌ها</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($services as $service): ?>
                        <tr>
                            <td>
                                <?php
                                if (!empty($service['service_date']) && $service['service_date'] !== '0000-00-00') {
                                    list($gy, $gm, $gd) = explode('-', $service['service_date']);
                                    list($jy, $jm, $jd) = gregorian_to_jalali($gy, $gm, $gd);
                                    $persian_date = convertToPersianNumbers("$jy/$jm/$jd");
                                    echo "<a href='service_items?service_id={$service['id']}' class='service-link'>$persian_date</a>";
                                } else {
                                    echo "نامشخص";
                                }
                                ?>
                            </td>
                            <td><?= htmlspecialchars($service['oil_type']) ?></td>
                            <td><?= convertToPersianNumbers(htmlspecialchars($service['next_kilometer'])) ?></td>
                            <td><?= htmlspecialchars($service['notes']) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php endif; ?>

        <a href="dashboard" class="btn-return">بازگشت به داشبورد</a>
    </div>
</body>
</html>

