<?php
require '../../../config/config.php';
include '../../../helpers/jdf.php';
session_start();

// بررسی لاگین مشتری
if (!isset($_SESSION['customer_logged_in'])) {
    header("Location: customer_login.php");
    exit();
}

$customer_id = $_SESSION['customer_id'];
$error_message = '';
$success_message = '';

try {
    // واکشی خودروهای ثبت‌شده برای مشتری
    $stmt = $pdo->prepare("SELECT * FROM customer_cars WHERE customer_id = ?");
    $stmt->execute([$customer_id]);
    $cars = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("خطایی رخ داد: " . $e->getMessage());
}

// افزودن خودرو جدید
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_car'])) {
    $car_model = trim($_POST['car_model']);
    $plate_part1 = trim($_POST['plate_part1']);
    $plate_part2 = trim($_POST['plate_part2']);
    $plate_part3 = trim($_POST['plate_part3']);
    $plate_part4 = trim($_POST['plate_part4']);

    if (empty($car_model) || empty($plate_part1) || empty($plate_part2) || empty($plate_part3) || empty($plate_part4)) {
        $error_message = "لطفاً تمام فیلدها را پر کنید.";
    } else {
        try {
            $stmt = $pdo->prepare("INSERT INTO customer_cars (customer_id, car_model, plate_part1, plate_part2, plate_part3, plate_part4) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$customer_id, htmlspecialchars($car_model), htmlspecialchars($plate_part1), htmlspecialchars($plate_part2), htmlspecialchars($plate_part3), htmlspecialchars($plate_part4)]);
            $success_message = "خودرو با موفقیت اضافه شد.";
            header("Refresh:0"); // بارگذاری مجدد صفحه
            exit();
        } catch (PDOException $e) {
            $error_message = "خطایی در ثبت خودرو رخ داد: " . $e->getMessage();
        }
    }
}

// تبدیل اعداد انگلیسی به فارسی
function englishToPersian($number) {
    $english = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
    $persian = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    return str_replace($english, $persian, $number);
}
?>
<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>داشبورد مشتری</title>
    <link rel="stylesheet" href="../../../public/css/dashboard.css">
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet">
</head>
<body>
    <div class="dashboard-container">
        <h1>داشبورد مشتری</h1>

        <!-- نمایش پیام‌های موفقیت و خطا -->
        <?php if ($success_message): ?>
            <div class="alert success"><?= $success_message ?></div>
        <?php endif; ?>
        <?php if ($error_message): ?>
            <div class="alert error"><?= $error_message ?></div>
        <?php endif; ?>

        <h2>خودروهای ثبت‌شده شما:</h2>
        <ul>
            <?php foreach ($cars as $car): ?>
                <li>
                    <a href="view_services.php?car_id=<?= $car['id'] ?>">
                        <?= htmlspecialchars($car['car_model']) ?> - <?= htmlspecialchars($car['plate_part4']) ?> <?= htmlspecialchars($car['plate_part3']) ?> <?= htmlspecialchars($car['plate_part2']) ?> <?= htmlspecialchars($car['plate_part1']) ?>
                    </a>
                </li>
            <?php endforeach; ?>
        </ul>

        <h2>اضافه کردن خودرو جدید</h2>
        <form method="POST" action="">
            <label for="car_model">مدل خودرو:</label>
            <input type="text" name="car_model" id="car_model" required>

            <label for="plate_part1">بخش اول پلاک:</label>
            <input type="text" name="plate_part1" id="plate_part1" maxlength="2" required>

            <label for="plate_part2">بخش دوم پلاک:</label>
            <input type="text" name="plate_part2" id="plate_part2" maxlength="1" required>

            <label for="plate_part3">بخش سوم پلاک:</label>
            <input type="text" name="plate_part3" id="plate_part3" maxlength="3" required>

            <label for="plate_part4">بخش چهارم پلاک:</label>
            <input type="text" name="plate_part4" id="plate_part4" maxlength="2" required>

            <button type="submit" name="add_car" class="btn-submit">اضافه کردن</button>
        </form>

        <a href="logout.php" class="btn-logout">خروج</a>
    </div>
</body>
</html>
