<?php
require '../../../config/config.php';
session_start();

$error_message = '';

// بررسی وجود customer_id در سشن
if (!isset($_SESSION['customer_id'])) {
    header("Location: customer_login.php");
    exit();
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['verify_otp'])) {
    $otp_code = trim($_POST['otp_code']);

    if (empty($otp_code)) {
        $error_message = "لطفاً کد OTP را وارد کنید.";
    } else {
        try {
            // دریافت کد OTP از دیتابیس
            $customer_id = $_SESSION['customer_id'];
            $stmt = $pdo->prepare("SELECT * FROM otp_codes WHERE customer_id = ? AND otp_code = ? AND expiry_time > NOW()");
            $stmt->execute([$customer_id, $otp_code]);
            $otp = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($otp) {
                // کد OTP معتبر است
                $_SESSION['customer_logged_in'] = true;

                // حذف کد OTP از دیتابیس بعد از استفاده
                $stmt = $pdo->prepare("DELETE FROM otp_codes WHERE customer_id = ?");
                $stmt->execute([$customer_id]);

                // ریدایرکت به صفحه داشبورد
                header("Location: customer_dashboard.php");
                exit();
            } else {
                $error_message = "کد OTP نامعتبر یا منقضی شده است.";
            }
        } catch (PDOException $e) {
            $error_message = "خطایی رخ داد: " . $e->getMessage();
        }
    }
}
?>


<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>سامانه مشتریان</title>
    <link rel="stylesheet" href="../../../public/css/login.css">
    <link href="https://cdn.fontcdn.ir/Font/Persian/Yekan/Yekan.css" rel="stylesheet">
</head>
<body>
<div class="login-container">
    <img src="../../../images/29513.png" alt="ورود مشتری" class="login-image">
    <h1>سامانه مشتریان اتوسرویس</h1>

    <?php if ($error_message): ?>
        <p class="error-message"><?= htmlspecialchars($error_message) ?></p>
    <?php endif; ?>

    <form method="POST">
        <!-- تغییرات اعمال شده در اینجا -->
        <input type="text" 
               id="otp_code" 
               name="otp_code" 
               inputmode="numeric" 
               onkeypress="return /[0-9]/i.test(event.key)" 
               maxlength="4" 
               required 
               placeholder="رمز دریافتی از طریق پیامک*">
        <button type="submit" name="verify_otp">ورود</button>
    </form>
    <p style="margin-top: 10px; color: #555;">نسخه 1.1.0</p>
</div>
</body>
</html>
